@@ -123,7 +123,7 @@ denominator of denom^(pdegree poly var)"
 		 (setf (cadr tail)
 		       (poly-subst (cadr tail) var repl))))
 	      (t (cond
-		  ((eq 0 (pdegree poly var)) nil)
+		  ((eql 0 (pdegree poly var)) nil)
 		  (t
 		   (do ((tail (cdr poly)(cddr tail))
 			(answer 0))
@@ -148,7 +148,7 @@ poly)
   (let ((tem (cond (vars-to-sub vars-to-sub)
 		   (t (loop for v in a-list collecting (car v)))))
 	deg)
-    (cond ((polynomialp poly)
+    (cond ((affine-polynomialp poly)
 	   (cond (degree (setq deg degree))
 		 (t(setq deg (poly-degree
 			       poly
@@ -228,7 +228,7 @@ poly)
 	   when (not  (pzerop  tem))
 	   collecting deg into lis
 	   collecting tem into lis
-	   finally (return (cond ((eq (car lis) 0) (second lis))
+	   finally (return (cond ((eql (car lis) 0) (second lis))
  				 (t (cons (p-var b) lis))))))))
 
 ;;incorrect doesn't take into account the
@@ -249,7 +249,7 @@ poly)
 	   when (not  (pzerop  tem))
 	   collecting deg into lis
 	   collecting tem into lis
-	   finally (return (cond ( (eq (car lis) 0)
+	   finally (return (cond ((eql (car lis) 0)
 				  (second lis))
 				 (t (cons (p-var b) lis))))))))
 
@@ -383,10 +383,10 @@ poly)
 	((get (car poly) 'constant)
 	 (loop for (deg cof) on (cdr poly) by #'cddr
 	       do (coll-linear1 cof)))
-	(t (cond ((and (eq (p-le poly) 1)
+	(t (cond ((and (eql (p-le poly) 1)
 		       (constant-functionp (p-lc poly)))
 		  (pushnew (p-var poly) *linear*)))
-	   (cond ((eq 0 (nth (- (length poly)  2) poly))
+	   (cond ((eql 0 (nth (- (length poly)  2) poly))
 		  (coll-linear1 (car (last poly)))))))
   ;;now must check these are really linear to remove the u collected above.
   (cond ((consp poly)
@@ -426,13 +426,13 @@ poly)
 	       do (cond ((get v 'disrep)
 			 (setq v (list v 1 1)))
 			(t (setq v (st-rat v))))
-	       else when (polynomialp v) nconc nil
+	       else when (affine-polynomialp v) nconc nil
 	       else do (setq v (new-rat v)) (setq a-denom t)
 		 (setq lcd (plcm lcd (denom v)))
 	       collecting v))
   (cond (a-denom
 	 (loop for v on new
-	    when (polynomialp (car v)) do (setf (car v)	(gen-ptimes lcd (car v)))
+	    when (affine-polynomialp (car v)) do (setf (car v)	(gen-ptimes lcd (car v)))
 	    else
 	    do (setf (car v) (gen-ptimes (num (car v)) (pquotient lcd (denom (car v)))))))
 	(t (setq new (subseq new 0 (length old)))))
@@ -444,7 +444,7 @@ poly)
 (defun simple-rat-sublis ( subs f &optional (switch t) &aux sub)
   (cond ((atom f) (cons f 1))
 	((and (numberp (car f))(numberp (cdr f))) f)
-	((polynomialp f)
+	((affine-polynomialp f)
 	 (setq sub (cdr (assoc (p-var f) subs :test #'equal)))
 	 (cond ((null sub)(setq sub (cons  (list  (p-var f) 1 1) 1))))
 	 (loop for (deg cof) on (cdr f) by #'cddr
@@ -463,7 +463,7 @@ poly)
 	for w in subs
 	when (not  (get v 'disrep))
 	do (setq v (add-newvar v))
-	do (cond ((polynomialp w)
+	do (cond ((affine-polynomialp w)
 		  (setq w (cons w 1)))
 		 ((rational-functionp w) nil)
 		 ((get w 'disrep)(setq w (cons (list w 1 1)1)))
