@@ -79,8 +79,8 @@
 	    (if mexplabel (setq mexplabel (quote-% mexplabel)))
 					; display the expression for TeX now:
 ;-	    (myprinc "$$")
-  	    (myprinc "")
-	    (mapc #'myprinc
+  	    (myprinc "" texport)
+	    (mapc #'(lambda (x) (myprinc x texport))
 		  ;;initially the left and right contexts are
 		  ;; empty lists, and there are implicit parens
 		  ;; around the whole expression
@@ -169,7 +169,7 @@
 ;-	      l (tex f (append l (list "\\left(")) (list "\\right)") 'mparen 'mparen))
   	      l (tex f (append l (list " left( ")) (list " right) ") 'mparen 'mparen))
 	(setq f (caar x)
-	      l (tex (texword f) l nil lop 'mfunction)))
+	      l (tex f l nil lop 'mfunction)))
     (setq
      r (nconc (tex-list (cdr x) nil (list "}") ",") r))
     (nconc l (list "_{") r  )))
@@ -242,8 +242,8 @@
 		 (expon (caddr x)) ;; this is the exponent
 		 (doit (and
 			f		; there is such a function
-			(member (getcharn f 1) '(#\% #\$)) ;; insist it is a % or $ function
-			(not (eq (car (last (car fx))) 'array))	; fix for x[i]^2
+			(member (get-first-char f) '(#\% #\$) :test #'char=) ;; insist it is a % or $ function
+			(not (member 'array (cdar fx) :test #'eq))	; fix for x[i]^2
 					; Jesper Harder <harder@ifa.au.dk>
 			(not (member f '(%sum %product %derivative %integrate %at
 				       %lsum %limit) :test #'eq)) ;; what else? what a hack...
