@@ -577,7 +577,7 @@
       (return
        (values rholen nil nil nil nil nil nil nil nil nfe nil iflag nil nil)))))
 
-(in-package #-gcl #:cl-user #+gcl "CL-USER")
+(in-package #:cl-user)
 #+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
 (eval-when (:load-toplevel :compile-toplevel :execute)
   (setf (gethash 'fortran-to-lisp::tangnf
