@@ -1,5 +1,13 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2006/12/21 03:42:11 
-;;; Using Lisp CMU Common Lisp CVS Head 2006-12-02 00:15:46 (19D)
+;;; Compiled by f2cl version:
+;;; ("f2cl1.l,v 2edcbd958861 2012/05/30 03:34:52 toy $"
+;;;  "f2cl2.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl3.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl4.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl5.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $"
+;;;  "f2cl6.l,v 1d5cbacbb977 2008/08/24 00:56:27 rtoy $"
+;;;  "macros.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $")
+
+;;; Using Lisp CMU Common Lisp 20d (20D Unicode)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -12,15 +20,16 @@
 (let* ((zero 0.0) (one 1.0) (two 2.0))
   (declare (type (double-float 0.0 0.0) zero)
            (type (double-float 1.0 1.0) one)
-           (type (double-float 2.0 2.0) two))
-  (let ((zswap
-         (make-array 4 :element-type 't :initial-contents '(nil nil t t)))
-        (rswap
-         (make-array 4 :element-type 't :initial-contents '(nil t nil t)))
-        (ipivot
+           (type (double-float 2.0 2.0) two)
+           (ignorable zero one two))
+  (let ((ipivot
          (make-array 16
                      :element-type 'f2cl-lib:integer4
-                     :initial-contents '(1 2 3 4 2 1 4 3 3 4 1 2 4 3 2 1))))
+                     :initial-contents '(1 2 3 4 2 1 4 3 3 4 1 2 4 3 2 1)))
+        (rswap
+         (make-array 4 :element-type 't :initial-contents '(nil t nil t)))
+        (zswap
+         (make-array 4 :element-type 't :initial-contents '(nil nil t t))))
     (declare (type (array f2cl-lib:integer4 (16)) ipivot)
              (type (array f2cl-lib:logical (4)) rswap zswap))
     (defun dlaln2
@@ -712,7 +721,7 @@
                    xnorm
                    info)))))))
 
-(in-package #-gcl #:cl-user #+gcl "CL-USER")
+(in-package #:cl-user)
 #+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
 (eval-when (:load-toplevel :compile-toplevel :execute)
   (setf (gethash 'fortran-to-lisp::dlaln2
