@@ -1,13 +1,13 @@
 ;;; Compiled by f2cl version:
-;;; ("f2cl1.l,v 1.215 2009/04/07 22:05:21 rtoy Exp $"
-;;;  "f2cl2.l,v 1.37 2008/02/22 22:19:33 rtoy Exp $"
-;;;  "f2cl3.l,v 1.6 2008/02/22 22:19:33 rtoy Exp $"
-;;;  "f2cl4.l,v 1.7 2008/02/22 22:19:34 rtoy Exp $"
-;;;  "f2cl5.l,v 1.200 2009/01/19 02:38:17 rtoy Exp $"
-;;;  "f2cl6.l,v 1.48 2008/08/24 00:56:27 rtoy Exp $"
-;;;  "macros.l,v 1.112 2009/01/08 12:57:19 rtoy Exp $")
+;;; ("f2cl1.l,v 2edcbd958861 2012/05/30 03:34:52 toy $"
+;;;  "f2cl2.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl3.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl4.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl5.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $"
+;;;  "f2cl6.l,v 1d5cbacbb977 2008/08/24 00:56:27 rtoy $"
+;;;  "macros.l,v 3fe93de3be82 2012/05/06 02:17:14 toy $")
 
-;;; Using Lisp CMU Common Lisp 19f (19F)
+;;; Using Lisp CMU Common Lisp 20d (20D Unicode)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':array)
@@ -58,10 +58,11 @@
           (tagbody
             (setf (f2cl-lib:fref work-%data% (j) ((1 *)) work-%offset%)
                     (dasum (f2cl-lib:int-sub j 1)
-                     (f2cl-lib:array-slice t$
+                     (f2cl-lib:array-slice t$-%data%
                                            double-float
                                            (1 j)
-                                           ((1 ldt) (1 *)))
+                                           ((1 ldt) (1 *))
+                                           t$-%offset%)
                      1))
            label10))
         (cond
@@ -159,10 +160,11 @@
                        ((> j1 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (- (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j1)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1 x 1)
                         (setf k (idamax (f2cl-lib:int-sub j1 1) x 1))
                         (setf xmax
@@ -181,10 +183,11 @@
                             var-8 var-9 var-10 var-11 var-12 var-13 var-14
                             var-15 var-16 var-17)
                          (dlaln2 f2cl-lib:%false% 2 1 smin one
-                          (f2cl-lib:array-slice t$
+                          (f2cl-lib:array-slice t$-%data%
                                                 double-float
                                                 (j1 j1)
-                                                ((1 ldt) (1 *)))
+                                                ((1 ldt) (1 *))
+                                                t$-%offset%)
                           ldt one one d 2 zero zero v 2 scaloc xnorm ierr)
                        (declare (ignore var-0 var-1 var-2 var-3 var-4 var-5
                                         var-6 var-7 var-8 var-9 var-10 var-11
@@ -218,17 +221,19 @@
                        ((> j1 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (- (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j1)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1 x 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (- (f2cl-lib:fref x-%data% (j2) ((1 *)) x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j2)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1 x 1)
                         (setf k (idamax (f2cl-lib:int-sub j1 1) x 1))
                         (setf xmax
@@ -275,10 +280,11 @@
                              (-
                               (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j1)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1 x 1)))
                      (setf xj
                              (abs
@@ -346,29 +352,32 @@
                              (-
                               (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j1)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1 x 1)))
                      (setf (f2cl-lib:fref d (2 1) ((1 2) (1 2)))
                              (-
                               (f2cl-lib:fref x-%data% (j2) ((1 *)) x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j2)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1 x 1)))
                      (multiple-value-bind
                            (var-0 var-1 var-2 var-3 var-4 var-5 var-6 var-7
                             var-8 var-9 var-10 var-11 var-12 var-13 var-14
                             var-15 var-16 var-17)
                          (dlaln2 f2cl-lib:%true% 2 1 smin one
-                          (f2cl-lib:array-slice t$
+                          (f2cl-lib:array-slice t$-%data%
                                                 double-float
                                                 (j1 j1)
-                                                ((1 ldt) (1 *)))
+                                                ((1 ldt) (1 *))
+                                                t$-%offset%)
                           ldt one one d 2 zero zero v 2 scaloc xnorm ierr)
                        (declare (ignore var-0 var-1 var-2 var-3 var-4 var-5
                                         var-6 var-7 var-8 var-9 var-10 var-11
@@ -513,10 +522,11 @@
                        ((> j1 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (- (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j1)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1 x 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (-
@@ -524,15 +534,17 @@
                                          ((f2cl-lib:int-add n j1))
                                          ((1 *))
                                          x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j1)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1
-                         (f2cl-lib:array-slice x
+                         (f2cl-lib:array-slice x-%data%
                                                double-float
                                                ((+ n 1))
-                                               ((1 *)))
+                                               ((1 *))
+                                               x-%offset%)
                          1)
                         (setf (f2cl-lib:fref x-%data% (1) ((1 *)) x-%offset%)
                                 (+
@@ -610,10 +622,11 @@
                             var-8 var-9 var-10 var-11 var-12 var-13 var-14
                             var-15 var-16 var-17)
                          (dlaln2 f2cl-lib:%false% 2 2 sminw one
-                          (f2cl-lib:array-slice t$
+                          (f2cl-lib:array-slice t$-%data%
                                                 double-float
                                                 (j1 j1)
-                                                ((1 ldt) (1 *)))
+                                                ((1 ldt) (1 *))
+                                                t$-%offset%)
                           ldt one one d 2 zero (- w) v 2 scaloc xnorm ierr)
                        (declare (ignore var-0 var-1 var-2 var-3 var-4 var-5
                                         var-6 var-7 var-8 var-9 var-10 var-11
@@ -660,17 +673,19 @@
                        ((> j1 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (- (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j1)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1 x 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (- (f2cl-lib:fref x-%data% (j2) ((1 *)) x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j2)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1 x 1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (-
@@ -678,15 +693,17 @@
                                          ((f2cl-lib:int-add n j1))
                                          ((1 *))
                                          x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j1)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1
-                         (f2cl-lib:array-slice x
+                         (f2cl-lib:array-slice x-%data%
                                                double-float
                                                ((+ n 1))
-                                               ((1 *)))
+                                               ((1 *))
+                                               x-%offset%)
                          1)
                         (daxpy (f2cl-lib:int-sub j1 1)
                          (-
@@ -694,15 +711,17 @@
                                          ((f2cl-lib:int-add n j2))
                                          ((1 *))
                                          x-%offset%))
-                         (f2cl-lib:array-slice t$
+                         (f2cl-lib:array-slice t$-%data%
                                                double-float
                                                (1 j2)
-                                               ((1 ldt) (1 *)))
+                                               ((1 ldt) (1 *))
+                                               t$-%offset%)
                          1
-                         (f2cl-lib:array-slice x
+                         (f2cl-lib:array-slice x-%data%
                                                double-float
                                                ((+ n 1))
-                                               ((1 *)))
+                                               ((1 *))
+                                               x-%offset%)
                          1)
                         (setf (f2cl-lib:fref x-%data% (1) ((1 *)) x-%offset%)
                                 (+
@@ -825,10 +844,11 @@
                              (-
                               (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j1)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1 x 1)))
                      (setf (f2cl-lib:fref x-%data%
                                           ((f2cl-lib:int-add n j1))
@@ -840,15 +860,17 @@
                                              ((1 *))
                                              x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j1)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1
-                               (f2cl-lib:array-slice x
+                               (f2cl-lib:array-slice x-%data%
                                                      double-float
                                                      ((+ n 1))
-                                                     ((1 *)))
+                                                     ((1 *))
+                                                     x-%offset%)
                                1)))
                      (cond
                        ((> j1 1)
@@ -1001,19 +1023,21 @@
                              (-
                               (f2cl-lib:fref x-%data% (j1) ((1 *)) x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j1)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1 x 1)))
                      (setf (f2cl-lib:fref d (2 1) ((1 2) (1 2)))
                              (-
                               (f2cl-lib:fref x-%data% (j2) ((1 *)) x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j2)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1 x 1)))
                      (setf (f2cl-lib:fref d (1 2) ((1 2) (1 2)))
                              (-
@@ -1022,15 +1046,17 @@
                                              ((1 *))
                                              x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j1)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1
-                               (f2cl-lib:array-slice x
+                               (f2cl-lib:array-slice x-%data%
                                                      double-float
                                                      ((+ n 1))
-                                                     ((1 *)))
+                                                     ((1 *))
+                                                     x-%offset%)
                                1)))
                      (setf (f2cl-lib:fref d (2 2) ((1 2) (1 2)))
                              (-
@@ -1039,15 +1065,17 @@
                                              ((1 *))
                                              x-%offset%)
                               (ddot (f2cl-lib:int-sub j1 1)
-                               (f2cl-lib:array-slice t$
+                               (f2cl-lib:array-slice t$-%data%
                                                      double-float
                                                      (1 j2)
-                                                     ((1 ldt) (1 *)))
+                                                     ((1 ldt) (1 *))
+                                                     t$-%offset%)
                                1
-                               (f2cl-lib:array-slice x
+                               (f2cl-lib:array-slice x-%data%
                                                      double-float
                                                      ((+ n 1))
-                                                     ((1 *)))
+                                                     ((1 *))
+                                                     x-%offset%)
                                1)))
                      (setf (f2cl-lib:fref d (1 1) ((1 2) (1 2)))
                              (- (f2cl-lib:fref d (1 1) ((1 2) (1 2)))
@@ -1098,10 +1126,11 @@
                             var-8 var-9 var-10 var-11 var-12 var-13 var-14
                             var-15 var-16 var-17)
                          (dlaln2 f2cl-lib:%true% 2 2 sminw one
-                          (f2cl-lib:array-slice t$
+                          (f2cl-lib:array-slice t$-%data%
                                                 double-float
                                                 (j1 j1)
-                                                ((1 ldt) (1 *)))
+                                                ((1 ldt) (1 *))
+                                                t$-%offset%)
                           ldt one one d 2 zero w v 2 scaloc xnorm ierr)
                        (declare (ignore var-0 var-1 var-2 var-3 var-4 var-5
                                         var-6 var-7 var-8 var-9 var-10 var-11
@@ -1158,7 +1187,7 @@
        end_label
         (return (values nil nil nil nil nil nil nil scale nil nil info))))))
 
-(in-package #-gcl #:cl-user #+gcl "CL-USER")
+(in-package #:cl-user)
 #+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
 (eval-when (:load-toplevel :compile-toplevel :execute)
   (setf (gethash 'fortran-to-lisp::dlaqtr
