@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -22,70 +22,70 @@
 
 (macsyma-module acall)
 
-(defmfun interval-error (fun low high)
+(defun interval-error (fun low high)
   (merror (intl:gettext "~@:M: lower bound ~M is greater than upper bound ~M") fun low high))
 
-(defmfun mfuncall (f &rest l)
+(defun mfuncall (f &rest l)
   (cond ((functionp f)
 	 (apply f l))
 	((and (symbolp f) (or (macro-function f) (special-operator-p f)))
 	 (eval (cons f l)))
 	(t
-	 (mapply f l nil))))
+	 (mapply f l f))))
 
 ;;; ((MQAPPLY ARRAY) X Y) is a strange form, meaning (X)[Y].
 
-(defmfun marrayref (aarray ind1 &rest inds &aux ap tem)
-  (declare (special fixunbound flounbound))
-  (case (ml-typep aarray)
-    ((array)
+(defun marrayref (aarray ind1 &rest inds)
+  (typecase aarray
+    (cl:array
      (case (array-element-type aarray)
        ((flonum fixnum t)
 	(apply #'aref aarray ind1 inds))
        (t
 	(merror (intl:gettext "MARRAYREF: encountered array ~M of unknown type.") aarray))))
-    ((hash-table)
-     (gethash (if inds (cons ind1 inds) inds) aarray))
-    ((symbol)
-     (cond ($use_fast_arrays
-	    (setq tem (and (boundp aarray) (symbol-value aarray)))
-	    (simplify (cond ((arrayp tem) (apply 'aref tem ind1 inds))
-			    ((hash-table-p tem)
-			     (gethash (if inds (cons ind1 inds) inds)
-				      tem))
-			    ((eq aarray 'mqapply)
-			     (apply #'marrayref ind1 inds))
-			    ((mget aarray 'hashar)
-			     (harrfind `((,aarray array) ,ind1 ,@inds)))
-			    ((symbolp tem)
-			     `((,tem array) ,ind1 ,@inds))
-			    (t (error "unknown type of array for use_fast_arrays. ~
+    (cl:hash-table
+     (gethash (if inds (cons ind1 inds) ind1) aarray))
+    (cl:symbol
+     (if $use_fast_arrays
+         (let ((tem (and (boundp aarray) (symbol-value aarray))))
+           (simplify (cond ((arrayp tem)
+                            (apply #'aref tem ind1 inds))
+                           ((hash-table-p tem)
+                            (gethash (if inds (cons ind1 inds) ind1) tem))
+                           ((eq aarray 'mqapply)
+                            (apply #'marrayref ind1 inds))
+                           ((mget aarray 'hashar)
+                            (harrfind `((,aarray array) ,ind1 ,@inds)))
+                           ((symbolp tem)
+                            `((,tem array) ,ind1 ,@inds))
+                           (t
+                            (error "unknown type of array for use_fast_arrays. ~
 			       the value cell should have the array or hash table")))))
-	   (t
-	    (simplify (cond ((setq ap (get aarray 'array))
-			     (let ((val (if (null inds)
-					    (aref ap ind1)
-					    (apply #'aref (append (list ap ind1) inds)))))
-			       ;; Check for KLUDGING array function implementation.
-			       (if (case (array-element-type ap)
-				     ((flonum) (= val flounbound))
-				     ((fixnum) (= val fixunbound))
-				     ((t) (eq val munbound))
-				     (t (merror (intl:gettext "MARRAYREF: encountered array pointer ~S of unknown type.") ap)))
-				   (arrfind `((,aarray ,aarray) ,ind1 ,@inds))
-				   val)))
-			    ((setq ap (mget aarray 'array))
-			     (arrfind `((,aarray array) ,ind1 ,@inds)))
-			    ((setq ap (mget aarray 'hashar))
-			     (harrfind `((,aarray array) ,ind1  ,@inds)))
-			    ((eq aarray 'mqapply)
-			     (apply #'marrayref ind1 inds))
-			    (t
-			     `((,aarray  array) ,ind1  ,@inds)))))))
-    ((list)
+         (let (ap)                      ; no fast arrays
+           (simplify (cond ((setq ap (get aarray 'array))
+                            (let ((val (if (null inds)
+                                           (aref ap ind1)
+                                           (apply #'aref (append (list ap ind1) inds)))))
+                              ;; Check for KLUDGING array function implementation.
+                              (if (case (array-element-type ap)
+                                    ((flonum) (= val flounbound))
+                                    ((fixnum) (= val fixunbound))
+                                    ((t) (eq val munbound))
+                                    (t (merror (intl:gettext "MARRAYREF: encountered array pointer ~S of unknown type.") ap)))
+                                  (arrfind `((,aarray array) ,ind1 ,@inds))
+                                  val)))
+                           ((setq ap (mget aarray 'array))
+                            (arrfind `((,aarray array) ,ind1 ,@inds)))
+                           ((setq ap (mget aarray 'hashar))
+                            (harrfind `((,aarray array) ,ind1  ,@inds)))
+                           ((eq aarray 'mqapply)
+                            (apply #'marrayref ind1 inds))
+                           (t
+                            `((,aarray  array) ,ind1  ,@inds)))))))
+    (cl:list
      (simplify (if (member (caar aarray) '(mlist $matrix) :test #'eq)
 		   (list-ref aarray (cons ind1 inds))
-		   `((mqapply aarray) ,aarray ,ind1 ,@inds))))
+		   `((mqapply array) ,aarray ,ind1 ,@inds))))
     (t
      (merror (intl:gettext "MARRAYREF: cannot retrieve an element of ~M") aarray))))
 
@@ -99,46 +99,49 @@
     (merror (intl:gettext "arraysetapply: second argument must be a list; found ~M") inds))
   (apply #'marrayset val ar (cdr inds)))
 
-(defmfun marrayset (val aarray &rest all-inds &aux ap (ind1 (first all-inds)) (inds (cdr all-inds)))
-  (case (ml-typep aarray)
-    ((array)
-     (case (array-element-type aarray)
-       ((fixnum flonum t)
-	(setf (apply #'aref aarray ind1 inds) val))
-       (t
-	(merror (intl:gettext "MARRAYSET: encountered array ~M of unknown type.") aarray))))
-    ((hash-table)
-     (setf (gethash (if (cdr all-inds)
-			(copy-list all-inds)
-			(car all-inds))
-		    aarray) val))
-    ((symbol)
-     (cond ((setq ap (get aarray 'array))
-	    (if (null inds)
-		(setf (aref ap ind1) val)
-		(setf (apply #'aref ap all-inds) val)))
-	   ((setq ap (mget aarray 'array))
-	    ;; the macsyma ARRAY frob is NOT an array pointer, it
-	    ;; is a GENSYM with a lisp array property, don't
-	    ;; ask me why.
-	    (if (null inds)
-		(setf (aref (symbol-array ap) ind1) val)
-		(setf (apply #'aref (symbol-array ap) all-inds) val)))
-	   ((setq ap (mget aarray 'hashar))
-	    (arrstore `((,aarray ,'array)
-			,@(mapcar #'(lambda (u) `((mquote simp) ,u)) all-inds))
-		      val))
-	   ((eq aarray 'mqapply)
-	    (apply #'marrayset val ind1 inds))
-	   (t
-	    (arrstore `((,aarray ,'array)
-			,@(mapcar #'(lambda (u) `((mquote simp) ,u)) all-inds))
-		      val))))
-    (list (if (member (caar aarray) '(mlist $matrix) :test #'eq)
-	      (list-ref aarray all-inds t val)
-	      (merror (intl:gettext "MARRAYSET: cannot assign to an element of ~M") aarray)))
-    (t
-     (merror (intl:gettext "MARRAYSET: ~M is not an array.") aarray)))
+(defun marrayset (val aarray &rest all-inds)
+  (let ((ind1 (first all-inds))
+        (inds (rest all-inds)))
+    (typecase aarray
+      (cl:array
+       (case (array-element-type aarray)
+         ((fixnum flonum t)
+          (setf (apply #'aref aarray ind1 inds) val))
+         (t
+          (merror (intl:gettext "MARRAYSET: encountered array ~M of unknown type.") aarray))))
+      (cl:hash-table
+       (setf (gethash (if (cdr all-inds)
+                          (copy-list all-inds)
+                          (car all-inds))
+                      aarray) val))
+      (cl:symbol
+       (let (ap)
+         (cond ((setq ap (get aarray 'array))
+                (if (null inds)
+                    (setf (aref ap ind1) val)
+                    (setf (apply #'aref ap all-inds) val)))
+               ((setq ap (mget aarray 'array))
+                ;; the macsyma ARRAY frob is NOT an array pointer, it
+                ;; is a GENSYM with a lisp array property, don't
+                ;; ask me why.
+                (if (null inds)
+                    (setf (aref (symbol-array ap) ind1) val)
+                    (setf (apply #'aref (symbol-array ap) all-inds) val)))
+               ((setq ap (mget aarray 'hashar))
+                (arrstore `((,aarray ,'array)
+                            ,@(mapcar #'(lambda (u) `((mquote simp) ,u)) all-inds))
+                          val))
+               ((eq aarray 'mqapply)
+                (apply #'marrayset val ind1 inds))
+               (t
+                (arrstore `((,aarray ,'array)
+                            ,@(mapcar #'(lambda (u) `((mquote simp) ,u)) all-inds))
+                          val)))))
+      (cl:list (if (member (caar aarray) '(mlist $matrix) :test #'eq)
+                   (list-ref aarray all-inds t val)
+                   (merror (intl:gettext "MARRAYSET: cannot assign to an element of ~M") aarray)))
+      (t
+       (merror (intl:gettext "MARRAYSET: ~M is not an array.") aarray)))      )
   val)
 
 ;;; Note that all these have HEADERS on the list. The CAR of a list I
@@ -170,14 +173,11 @@
 	(t
 	 (list-ref (list-ref l `(,(car indexl))) (cdr indexl)))))
 
-(declare-top (special $dispflag))
-
-(defmfun display-for-tr (labelsp equationsp &rest argl)
-  (declare (special *linelabel*))
+(defun display-for-tr (labelsp equationsp &rest argl)
   (do ((argl argl (cdr argl))
        (lablist nil)
        (tim 0))
-      ((null argl) (if labelsp `((mlist) ,@lablist) '$done))
+      ((null argl) (if labelsp `((mlist) ,@(nreverse lablist)) '$done))
     (let ((ans (car argl)))
       (cond ((and equationsp
 		  ;; ((MEQUAL) FOO BAR)
@@ -197,12 +197,13 @@
 	(unless $nolabels
 	  (setf (symbol-value *linelabel*) ans)))
       (setq tim (get-internal-run-time))
-      (displa `((mlabel) ,(cond (labelsp *linelabel*)) ,ans))
+      (let ((*display-labels-p* (not (null lablist))))
+	(displa `((mlabel) ,(cond (labelsp *linelabel*)) ,ans)))
       (mterpri)
       (timeorg tim))))
 
 
-(defmfun insure-array-props (fnname ignore-mode number-of-args &aux ary)
+(defun insure-array-props (fnname ignore-mode number-of-args &aux ary)
   (declare (ignore ignore-mode))
   ;; called during load or eval time by the defining forms
   ;; for translated array-functions.
@@ -221,7 +222,7 @@
 	     (add2lnc fnname $arrays)
 	     (setq ary (mgetl fnname '(hashar array))))
 	 (unless (= (if (eq (car ary) 'hashar)
-			(funcall (cadr ary) 2)
+			(aref (symbol-array (cadr ary)) 2)
 			(length (cdr (arraydims (cadr ary)))))
 		    number-of-args)
 	   (merror (intl:gettext "INSURE-ARRAY-PROPS: array ~:@M already defined with different dimensions.") fnname)))
@@ -235,18 +236,16 @@
 
 ;;; An entry point to $APPLY for translated code.
 
-(defmfun mapply-tr (fun list)
+(defun mapply-tr (fun list)
   (unless ($listp list)
     (merror (intl:gettext "apply: second argument must be a list; found ~M") list))
   (mapply1 fun (cdr list) '|the first arg to a translated `apply'| list))
 
-(defmfun assign-check (var val)
+(defun assign-check (var val)
   (let ((a (get var 'assign)))
     (if a (funcall a var val))))
 
-(declare-top (special maplp))
-
-(defmfun maplist_tr (fun  l1 &rest l)
+(defun maplist_tr (fun  l1 &rest l)
   (setq l (cons l1 (copy-list l)))
   (simplify (let ((maplp t) res)
 	      (setq res (apply #'map1 (getopr fun) l))
@@ -260,75 +259,74 @@
 ;;; to call the function IS because double-evaluation will then
 ;;; result, which is wrong, not to mention being incompatible with
 ;;; the interpreter.
-;;;
-;;; This code is taken from the COMPAR module, and altered such that calls to
-;;; the macsyma evaluator do not take place. It would be a lot
-;;; better to simply modify the code in COMPAR! However, mumble...
-;;; Anyway, be careful of changes to COMPAR that break this code.
 
-(defmfun is-boole-check (form)
-  (cond ((null form) nil)
-	((eq form t) t)
+(defun boole-verify (form error? $unknown?)
+  (cond ((typep form 'boolean)
+         form)
+        (error?
+         (pre-err form))
+        ($unknown?
+         '$unknown)
+        (t
+         form)))
+
+(defun boole-eval (form error? $unknown?)
+  (if (typep form 'boolean)
+      form
+      (let ((ans (mevalp_tr form error?)))
+        (if (or (typep ans 'boolean)
+                (not $unknown?))
+            ans
+            '$unknown))))
+
+(defun $is-boole-verify (form)
+  (boole-verify form $prederror t))
+
+(defun $is-boole-eval (form)
+  (boole-eval form $prederror t))
+
+(setf (get '$is 'tr-boole-verify) '$is-boole-verify)
+(setf (get '$is 'tr-boole-eval) '$is-boole-eval)
+
+(defun $maybe-boole-verify (form)
+  (boole-verify form nil t))
+
+(defun $maybe-boole-eval (form)
+  (boole-eval form nil t))
+
+(setf (get '$maybe 'tr-boole-verify) '$maybe-boole-verify)
+(setf (get '$maybe 'tr-boole-eval) '$maybe-boole-eval)
+
+(defun mcond-boole-verify (form)
+  (boole-verify form $prederror nil))
+
+(defun mcond-boole-eval (form)
+  (boole-eval form $prederror nil))
+
+(setf (get 'mcond 'tr-boole-verify) 'mcond-boole-verify)
+(setf (get 'mcond 'tr-boole-eval) 'mcond-boole-eval)
+
+(defun mevalp_tr (pat error?)
+  (boole-verify (mevalp1_tr pat error?) error? nil))
+
+(defun mevalp1_tr (pat error?)
+  (cond ((atom pat) pat)
+	((member (caar pat) '(mnot mand mor) :test #'eq)
+	 (flet ((pred-eval (o) (mevalp_tr o error?)))
+	   (cond ((eq 'mnot (caar pat)) (is-mnot #'pred-eval (cadr pat)))
+	         ((eq 'mand (caar pat)) (is-mand #'pred-eval (cdr pat)))
+	         (t (is-mor #'pred-eval (cdr pat))))))
 	(t
-	 ;; We check for T and NIL quickly, otherwise go for the database.
-	 (mevalp_tr form $prederror nil))))
-
-(defmfun maybe-boole-check (form)
-  (mevalp_tr form nil nil))
-
-(defun mevalp_tr (pat error? meval?)
-  (let (patevalled ans)
-    (setq ans (mevalp1_tr pat error? meval?))
-    (cond ((member ans '(t nil) :test #'eq) ans)
-	  (error?
-	   (pre-err patevalled))
-	  ('else '$unknown))))
-
-(defun mevalp1_tr (pat error? meval?)
-  (let (patevalled)
-    (cond ((and (not (atom pat)) (member (caar pat) '(mnot mand mor) :test #'eq))
-	   (cond ((eq 'mnot (caar pat)) (is-mnot_tr (cadr pat) error? meval?))
-		 ((eq 'mand (caar pat)) (is-mand_tr (cdr pat) error? meval?))
-		 (t (is-mor_tr (cdr pat) error? meval?))))
-	  ((atom (setq patevalled (if meval? (meval pat) pat))) patevalled)
-	  ((member (caar patevalled) '(mnot mand mor) :test #'eq) (mevalp1_tr patevalled
-									      error?
-									      meval?))
-	  (t (mevalp2 patevalled (caar patevalled) (cadr patevalled) (caddr patevalled))))))
-
-(defun is-mnot_tr (pred error? meval?)
-  (setq pred (mevalp_tr pred error? meval?))
-  (cond ((eq t pred) nil)
-	((not pred))
-	(t (pred-reverse pred))))
-
-(defun is-mand_tr (pl error? meval?)
-  (do ((dummy) (npl))
-      ((null pl) (cond ((null npl))
-		       ((null (cdr npl)) (car npl))
-		       (t (cons '(mand) (nreverse npl)))))
-    (setq dummy (mevalp_tr (car pl) error? meval?)
-	  pl (cdr pl))
-    (cond ((eq t dummy))
-	  ((null dummy) (return nil))
-	  (t (setq npl (cons dummy npl))))))
-
-(defun is-mor_tr (pl error? meval?)
-  (do ((dummy) (npl))
-      ((null pl) (cond ((null npl) nil)
-		       ((null (cdr npl)) (car npl))
-		       (t (cons '(mor) (nreverse npl)))))
-    (setq dummy (mevalp_tr (car pl) error? meval?)
-	  pl (cdr pl))
-    (cond ((eq t dummy) (return t))
-	  ((null dummy))
-	  (t (setq npl (cons dummy npl))))))
+	 (let ((ans (mevalp2 pat (caar pat) (cadr pat) (caddr pat))))
+	   (if (typep ans 'boolean)
+	       ans
+	       pat)))))
 
 ;; Some functions for even faster calling of arrays.
 
 (defun marrayref1$ (aarray index)
-  (case (ml-typep aarray)
-    ((aarray)
+  (typecase aarray
+    (cl:array
      (case (array-element-type aarray)
        ((flonum) (aref aarray index))
        (t (merror (intl:gettext "MARRAYREF1$: array must be an array of floats; found ~M") aarray))))
@@ -336,8 +334,8 @@
      (marrayref aarray index))))
 
 (defun marrayset1$ (value aarray index)
-  (case (ml-typep aarray)
-    ((aarray)
+  (typecase aarray
+    (cl:array
      (case (array-element-type aarray)
        ((flonum) (setf (aref aarray index) value))
        (t (merror (intl:gettext "MARRAYSET1$: array must be an array of floats; found ~M") aarray))))
@@ -345,7 +343,7 @@
      (marrayset value aarray index))))
 
 
-(defmfun application-operator (form &rest ign)
+(defun application-operator (form &rest ign)
   (declare (ignore ign))
   (apply (caar form) (cdr form)))
 
@@ -356,7 +354,7 @@
       (- x)
       (simplify (list '(mminus) x))))
 
-(defmfun retlist_tr (&rest args)
+(defun retlist_tr (&rest args)
   (do ((j (- (length args) 2) (- j 2))
        (l () (cons (list '(mequal simp) (nth j args) (nth (1+ j) args)) l)))
       ((< j 0) (cons '(mlist simp) l))))
