@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -13,8 +13,6 @@
 
 (macsyma-module fcall)
 
-(transl-module fcall)
-
 ;;; Bug-Fixes:
 ;;;
 ;;; 11/15/80	KMP	Remove *TRIED-TO-AUTOLOAD* as a global and replaced
@@ -47,22 +45,23 @@
 	(t
 	 (push (cons f type) *tr-runtime-warned*)
 	 (when $tr_warn_bad_function_calls
-	   (let ((tabl (cdr (assoc type '((fexpr . (fexpr-warnedp "This may be due to lack of enough translation data *print-base* info."))
-					 (macro . (macro-warnedp "Macros should to be loaded when you are translating."))
-					 (undefined . (undefined-warnp "The function was totaly undefined. Maybe you want to quote it."))
+	   (let ((tabl (cdr (assoc type '((macro . (macro-warnedp "Macros should be loaded when you are translating."))
+					 (undefined . (undefined-warnp "The function was totally undefined. Maybe you want to quote it."))
 					 (punt-nil . (punt-nil-warnp "If you want the value of the function name, use `apply'"))
-					 (mfexpr . (mfexpr-warnedp "MFEXPRS should be loaded at translating time. Use of them in translated code (nay, any code!), is NOT recommened however.")))
+					 (mfexpr . (mfexpr-warnedp "MFEXPRS should be loaded at translating time. Use of them in translated code (nay, any code!), is NOT recommended however.")))
 				   :test #'eq))))
 	     (cond ((null tabl))
 		   ((get f (car tabl)))
 		   (t
 		    (putprop f t (car tabl))
 		    (terpri)
+		    (finish-output)
 		    (princ "Warning: ")
 		    (mgrind f nil)
 		    (princ " has a function or macro call which has not been translated properly.")
 		    (cond ((cdr tabl)
 			   (terpri)
+			   (finish-output)
 			   (princ (cadr tabl)))))))))))
 
 (defun mapcar-eval (x)
@@ -74,13 +73,14 @@
       ;;loses if the argl could not be evaluated but macsyma &quote functions
       ;;but the translator should be fixed so that if (mget f 'mfexprp) is t
       ;;then it doesn't translate as an mfunction-call.
-      `(lispm-mfunction-call-aux ',f ',argl (list ,@ argl) nil)))
+      `(mfunction-call-aux ',f ',argl nil)))
 
-(defun lispm-mfunction-call-aux (f argl list-argl autoloaded-already? &aux f-prop)
+(defun mfunction-call-aux (f argl autoloaded-already? &aux f-prop)
   (cond ((functionp f)
-	 (apply f list-argl))
+	 (apply f (mapcar-eval argl)))
 	((macro-function f)
-	 (eval (cons f list-argl)))
+	 (mfunction-call-warn f 'macro)
+	 (eval (cons f argl)))
 	((not (symbolp f)) (merror (intl:gettext "apply: expected symbol or function; found: ~M") f))
 	((setq f-prop (get f 'mfexpr*))
 	 (funcall f-prop (cons nil argl)))
@@ -89,20 +89,19 @@
 		(mfunction-call-warn f 'mfexpr)
 		(meval (cons (list f) argl)))
 	       (t
-		(mlambda f-prop list-argl f t nil))))
+		(mlambda f-prop (mapcar-eval argl) f t nil))))
 	((setq f-prop (get f 'autoload))
 	 (cond (autoloaded-already?
 		(merror (intl:gettext "apply: function ~:@M undefined after loading file ~A") f (namestring (get f 'autoload))))
 	       (t
 		(funcall autoload (cons f f-prop))
-		(lispm-mfunction-call-aux f argl list-argl t))))
-
+		(mfunction-call-aux f argl t))))
 	((boundp f)
 	 (mfunction-call-warn f 'punt-nil)
-	 (mapply (eval f) (mapcar-eval argl) f))
+	 (mapply (symbol-value f) (mapcar-eval argl) f))
 	(t
 	 (mfunction-call-warn f 'undefined)
-	 `((,f) ,@ list-argl))))
+	 `((,f) ,@(mapcar-eval argl)))))
 
 (defquote trd-msymeval (&rest l)
   (let ((a-var? (car l)))
@@ -110,63 +109,21 @@
 	(eval a-var?) ;;; ouch!
 	(setf (symbol-value a-var?) (if (cdr l) (eval (cadr l))  a-var?))))) ;; double ouch!
 
-(defun expt$ (a b)
-  (expt a b))
+(defun maybe-msymeval (var)
+  (if (boundp var)
+      (symbol-value var)
+      var))
 
 ;;; These are the LAMBDA forms. They have macro properties that set
 ;;; up very different things in compiled code.
 
-(defvar *fcall-memory* nil
-  "This ALIST will never be very long. Considerably less hairy then
-	a hashing scheme, perhaps faster in normal use. In either case
-	there is the problem of garbage from red-defined functions.")
-
-(defun evalquote (exp)
-  (setq exp (eval exp))
-  (if (numberp exp)
-      exp
-      `(quote ,exp)))
-
 ;;; (FUNGEN&ENV-for-meval <eval vars list> <late eval vars list>  <EXP>)
 ;;won't work in cl.  fix later.
 (defquote fungen&env-for-meval (&rest args)
-  (destructuring-let (((evl levl . body) args))
+  (destructuring-let (((evl nil . body) args))
 	    ;;; all we want to do here is make sure that the EVL gets
 	    ;;; evaluated now so that we have some kind of compatibility
 	    ;;; with compiled code. we could just punt and pass the body.
 		     `(($apply) ((mquote) ((lambda) ((mlist) ,@evl) ,@body))
 		       ((mquote simp) ((mlist) ,@(mapcar-eval evl))))))
 
-;;; The following code depends on the fact that the argument to an
-;;; FEXPR is always EQ, for a given instance of FEXPR call. Lets say
-;;; that the efficiency of the code depends on that fact. We cannot use
-;;; displacing macros because of the $SAVE problem which I really don't
-;;; feel like fooling around with since it is an IN-CORE function, and
-;;; totaly cryptic code.
-
-(defquote fungen&env-for-mevalsumarg (&rest args)
-  (let ((res (assoc args *fcall-memory* :test #'eq)))
-    (cond ((null res)
-	   (destructuring-let (((evl levl t-body m-body) args))
-			      (setq res (gensym))
-			      (putprop res
-				       (coerce
-					`(lambda (*ignored*)
-					   (prog2
-					       (mbind ',evl (get ',res 'sumarg-env) nil)
-					       (mevalatoms ',m-body)
-					     (munbind ',evl)))
-					'function)
-				       'mevalsumarg-macro)
-			      (setf (symbol-function res)
-				    (coerce
-				     `(lambda ()
-					(apply #'(lambda ,evl ,t-body) (get ',res 'sumarg-env)))
-				     'function))
-			      (setq res `(,args ,res ((,res))))
-			      (push res *fcall-memory*))))
-    (putprop (cadr res) (mapcar #'eval (car args)) 'sumarg-env)
-    (caddr res)))
-
-(defquote m-tlambda-i (&rest args)
-  `(lambda ,@(cddr args)))
