@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -12,7 +12,7 @@
 
 (macsyma-module newinv)
 
-(declare-top (special *ptr* *ptc* *iar* *nonz* detl* *r0 mul* $sparse *det* *rr* ax))
+(declare-top (special *ptr* *ptc* *iar* *nonz* detl* *rr*))
 
 (defun multbk (l ax m)
   (prog (e)
@@ -48,7 +48,7 @@
      (setq ro (cdr ro))
      (go loop2)))
 
-(defun prodhk (ri d r m)
+(defun prodhk (ax ri d r m)
   (declare (fixnum r m))
   (prog (ei e *rr* *r0 co)
      (setq *r0 r ei ri)
@@ -59,7 +59,7 @@
 			       (mapcar #'(lambda (x y) (nconc x (list y)))
 				       ri (nreverse *rr*))))))
      (setq e (car ei) ei (cdr ei))
-     (setq co (cons (bmhk e d co r detl*) co))
+     (setq co (cons (bmhk ax e d co r detl* *r0) co))
      (go loop)))
 
 (defun obmtrx (ax r s i j)
@@ -81,7 +81,7 @@
      (setq dr (cons d dr))
      (go loop1)))
 
-(defun bmhk (da b nc c0 detl)
+(defun bmhk (ax da b nc c0 detl *r0)
   (prog (c a sum det dy *nonz* x y)
      (setq det (car b) b (cdr b) a (car da) da (cdr da))
      (setq nc (reverse nc))
@@ -101,15 +101,12 @@
      on  (setq det (cons (ptimes (pminus (caar a)) (car det)) 1))
      (return (cons det (multmat(cdr a) sum)))))
 
-(declare-top (special bl))
-
 ;; tmlattice returns the block structure in the form of a list of blocks
 ;; each in the form of ((i1 j1) (i2 j2) etc))
 
 (defun newinv (ax m n)
   (declare (fixnum m n ))
   (prog (j mmat bl d bm detl* dm ipdm dm2 r i ei)
-     (declare (special bl))	       ;Why?  I don't know why.  --gsb
      (do ((i m (1- i)))
 	 ((= i 0))
        (declare (fixnum i))
@@ -145,10 +142,10 @@
 		 (setq ei (list ei))(go next)))
      (setq d (tmlin '*iar* dm dm dm))
      (setq d (cons (caar d) (cdr d)))
-     (setq ei (prodhk ei d r m))
+     (setq ei (prodhk ax ei d r m))
      (setq d nil)
      next  (incf r (car bl))
      (setq bl (cdr bl))
      (go loop1)))
 
-(declare-top (unspecial bl *nonz* detl* *r0 mul* *det* *rr* ax))
+(declare-top (unspecial *nonz* detl* *rr*))
