@@ -13,7 +13,7 @@
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (setf lisp::*enable-package-locked-errors* nil))
 
-(in-package #-gcl #:bigfloat #+gcl "BIGFLOAT")
+(in-package #:bigfloat)
 
 (defun intofp (re)
   ;; Kind of like Maxima's INTOFP, but we only handle numeric types.
@@ -159,6 +159,7 @@
 ;; numbers, we return one more than the max of the exponent of the
 ;; real and imaginary parts.
 (defmethod max-exponent ((x bigfloat))
+  ;; The third element is the exponent of a bigfloat.
   (cl:abs (third (slot-value x 'real))))
 
 (defmethod max-exponent ((x complex-bigfloat))
@@ -166,10 +167,14 @@
 		 (cl:abs (third (slot-value x 'imag))))))
 
 (defmethod max-exponent ((x cl:float))
-  (cl:abs (nth-value 1 (cl:decode-float x))))
+  (if (zerop x)
+      0
+      (cl:abs (nth-value 1 (cl:decode-float x)))))
 
 (defmethod max-exponent ((x cl:rational))
-  (cl:ceiling (cl:log (cl:abs x) 2)))
+  (if (zerop x)
+      0
+      (cl:ceiling (cl:log (cl:abs x) 2))))
 
 (defmethod max-exponent ((x cl:complex))
   (cl:1+ (cl:max (max-exponent (cl:realpart x))
@@ -183,7 +188,8 @@
 ;; up by the log(x).  The "size" of a is, basically, the exponent of
 ;; a. If a = 2^n*f where |f| < 1, then the size is abs(n) because
 ;; that's how many extra bits are added to the integer part of
-;; a*log(x).
+;; a*log(x).  If either |x| or |a| < 1, the size is 0, since no
+;; additional bits are taken up.
 (defun expt-extra-bits (x a)
   (max 1 (+ (integer-length (max-exponent x))
 	    (max-exponent a))))
@@ -219,22 +225,9 @@
      
 ;;; REALP
 
-;; GCL doesn't have the REAL class!  But since a real is a rational or
-;; float, we can fake it by defining methods on rationals and floats
-;; for gcl.
-#-gcl
 (defmethod realp ((x cl:real))
   t)
 
-#+gcl
-(progn
-  (defmethod realp ((x cl:rational))
-    t)
-  (defmethod realp ((x cl:float))
-    t)
-  )
-  
-
 (defmethod realp ((x bigfloat))
   t)
 
@@ -830,7 +823,7 @@
 (defun = (number &rest more-numbers)
   "Returns T if all of its arguments are numerically equal, NIL otherwise."
   (declare (optimize (safety 2))
-	   #-gcl (dynamic-extent more-numbers))
+	   (dynamic-extent more-numbers))
   (do ((nlist more-numbers (cdr nlist)))
       ((atom nlist) t)
     (declare (list nlist))
@@ -840,7 +833,7 @@
 (defun /= (number &rest more-numbers)
   "Returns T if no two of its arguments are numerically equal, NIL otherwise."
   (declare (optimize (safety 2))
-	   #-gcl (dynamic-extent more-numbers))
+	   (dynamic-extent more-numbers))
   (do* ((head number (car nlist))
 	(nlist more-numbers (cdr nlist)))
        ((atom nlist) t)
@@ -871,7 +864,7 @@
 	    (defun ,op (number &rest more-numbers)
 	      "Returns T if its arguments are in strictly increasing order, NIL otherwise."
 	      (declare (optimize (safety 2))
-		       #-gcl (dynamic-extent more-numbers))
+		       (dynamic-extent more-numbers))
 	      (do* ((n number (car nlist))
 		    (nlist more-numbers (cdr nlist)))
 		   ((atom nlist) t)
@@ -957,8 +950,7 @@
   "The first argument is some location holding a number. This number is
   incremented by the second argument, DELTA, which defaults to 1."
   (multiple-value-bind (dummies vals newval setter getter)
-      (#-gcl get-setf-expansion #+gcl get-setf-method
-	     place env)
+      (get-setf-expansion place env)
     (let ((d (gensym)))
       `(let* (,@(mapcar #'list dummies vals)
               (,d ,delta)
@@ -969,8 +961,7 @@
   "The first argument is some location holding a number. This number is
   decremented by the second argument, DELTA, which defaults to 1."
   (multiple-value-bind (dummies vals newval setter getter)
-      (#-gcl get-setf-expansion #+gcl get-setf-method
-	     place env)
+      (get-setf-expansion place env)
     (let ((d (gensym)))
       `(let* (,@(mapcar #'list dummies vals)
               (,d ,delta)
@@ -1116,8 +1107,7 @@
 
 (defmethod acosh ((x bigfloat))
   (let* ((r (real-value x))
-	 (value (maxima::mevalp `((maxima::%acosh maxima::simp)
-				  ,r))))
+	 (value (maxima::meval `((maxima::%acosh maxima::simp) ,r))))
     (if (maxima::bigfloatp value)
 	(make-instance 'bigfloat :real value)
 	(make-instance 'complex-bigfloat
@@ -1140,10 +1130,10 @@
 		  (to res))))
 	   (let ((max-op (intern (concatenate 'string "$" (string name)) '#:maxima)))
 	     `(defmethod ,name ((a complex-bigfloat))
-		;; We should do something better than calling mevalp
+		;; We should do something better than calling meval
 		(let* ((arg (maxima::add (real-value a)
 					 (maxima::mul 'maxima::$%i (imag-value a))))
-		       (result (maxima::mevalp `((,',max-op maxima::simp) ,arg))))
+		       (result (maxima::meval `((,',max-op maxima::simp) ,arg))))
 		  (to result)))))))
   (frob exp)
   (frob sin)
@@ -1165,32 +1155,16 @@
   (make-instance 'bigfloat
 		 :real (maxima::bcons (maxima::fpatan (cdr (real-value a))))))
 
-(defmethod one-arg-atan ((a complex-bigfloat))
-  ;; We should do something better than calling mevalp
-  (let* ((arg (maxima::add (real-value a)
-			   (maxima::mul 'maxima::$%i (imag-value a))))
-	 (result (maxima::mevalp `((maxima::%atan maxima::simp) ,arg))))
-    (make-instance 'complex-bigfloat
-		   :real (maxima::$realpart result)
-		   :imag (maxima::$imagpart result))))
+(defmethod one-arg-atan ((z complex-bigfloat))
+  ;; atan(z) = -i * atanh(i*z)
+  (let* ((iz (complex (- (imagpart z)) (realpart z)))
+         (result (atanh iz)))
+    (complex (imagpart result)
+             (- (realpart result)))))
 
-;; Really want type real, but gcl doesn't like that.  Define methods for rational and float
-#-gcl
 (defmethod two-arg-atan ((a real) (b real))
   (cl:atan a b))
 
-#+gcl
-(progn
-  (defmethod two-arg-atan ((a cl:float) (b cl:float))
-    (cl:atan a b))
-  (defmethod two-arg-atan ((a cl:rational) (b cl:rational))
-    (cl:atan a b))
-  (defmethod two-arg-atan ((a cl:float) (b cl:rational))
-    (cl:atan a b))
-  (defmethod two-arg-atan ((a cl:rational) (b cl:float))
-    (cl:atan a b))
-  )
-
 (defmethod two-arg-atan ((a bigfloat) (b bigfloat))
   (make-instance 'bigfloat
 		 :real (maxima::bcons
@@ -1286,8 +1260,8 @@
 
 (defmethod cis ((a bigfloat))
   (make-instance 'complex-bigfloat
-		 :real (maxima::bcons (maxima::fpsin (cdr (real-value a)) t))
-		 :imag (maxima::bcons (maxima::fpsin (cdr (real-value a)) nil))))
+		 :real (maxima::bcons (maxima::fpsin (cdr (real-value a)) nil))
+		 :imag (maxima::bcons (maxima::fpsin (cdr (real-value a)) t))))
 
 (defmethod phase ((a bigfloat))
   (let ((r (cdr (real-value a))))
@@ -1303,7 +1277,7 @@
 (defun max (number &rest more-numbers)
   "Returns the greatest of its arguments."
   (declare (optimize (safety 2)) (type (or real bigfloat) number)
-	   #-gcl (dynamic-extent more-numbers))
+	   (dynamic-extent more-numbers))
   (dolist (real more-numbers)
     (when (> real number)
       (setq number real)))
@@ -1312,7 +1286,7 @@
 (defun min (number &rest more-numbers)
   "Returns the least of its arguments."
   (declare (optimize (safety 2)) (type (or real bigfloat) number)
-	   #-gcl (dynamic-extent more-numbers))
+	   (dynamic-extent more-numbers))
   (do ((nlist more-numbers (cdr nlist))
        (result (the (or real bigfloat) number)))
       ((null nlist) (return result))
@@ -1320,41 +1294,17 @@
     (if (< (car nlist) result)
 	(setq result (car nlist)))))
 
-;; We really want a real type, but gcl doesn't like it, so use number
-;; instead.
-#-gcl
 (defmethod one-arg-complex ((a real))
   (cl:complex a))
 
-#+gcl
-(progn
-(defmethod one-arg-complex ((a cl:float))
-  (cl:complex a))
-(defmethod one-arg-complex ((a cl:rational))
-  (cl:complex a))
-)
-
 (defmethod one-arg-complex ((a bigfloat))
   (make-instance 'complex-bigfloat
 		 :real (real-value a)
 		 :imag (intofp 0)))
 
-#-gcl
 (defmethod two-arg-complex ((a real) (b real))
   (cl:complex a b))
 
-#+gcl
-(progn
-(defmethod two-arg-complex ((a cl:float) (b cl:float))
-  (cl:complex a b))
-(defmethod two-arg-complex ((a cl:rational) (b cl:rational))
-  (cl:complex a b))
-(defmethod two-arg-complex ((a cl:float) (b cl:rational))
-  (cl:complex a b))
-(defmethod two-arg-complex ((a cl:rational) (b cl:float))
-  (cl:complex a b))
-)
-
 (defmethod two-arg-complex ((a bigfloat) (b bigfloat))
   (make-instance 'complex-bigfloat
 		 :real (real-value a)
@@ -1386,10 +1336,17 @@
       (one-arg-complex a)))
 
 (defmethod unary-floor ((a bigfloat))
-  ;; fpentier truncates to zero, so adjust for negative numbers.
-  (if (minusp a)
-      (maxima::fpentier (real-value (- a 1)))
-      (maxima::fpentier (real-value a))))
+  ;; fpentier truncates to zero, so adjust for negative numbers
+  (let ((trunc (maxima::fpentier (real-value a))))
+    (cond ((minusp a)
+	   ;; If the truncated value is the same as the original,
+	   ;; there's nothing to do because A was an integer.
+	   ;; Otherwise, we need to subtract 1 to make it the floor.
+	   (if (= trunc a)
+	       trunc
+	       (1- trunc)))
+	  (t
+	   trunc))))
 
 (defmethod unary-ffloor ((a bigfloat))
   ;; We can probably do better than converting to an integer and
@@ -1496,7 +1453,7 @@
 	  (bigfloat 1))
       (cond ((and (zerop a) (plusp (realpart b)))
 	     (* a b))
-	    ((and (typep b 'bigfloat) (= b (truncate b)))
+	    ((and (realp b) (= b (truncate b)))
 	     ;; Use the numeric^number method because it can be much
 	     ;; more accurate when b is an integer.
 	     (expt a (truncate b)))
@@ -1514,10 +1471,10 @@
 	  (bigfloat 1))
       (cond ((and (zerop a) (plusp (realpart b)))
 	     (* a b))
-	    ((= b (truncate b))
+	    ((and (realp b) (= b (truncate b)))
 	     (with-extra-precision ((expt-extra-bits a b)
 				    (a b))
-	       (expt a (truncate b))))
+	       (intofp (expt a (truncate b)))))
 	    (t
 	     (with-extra-precision ((expt-extra-bits a b)
 				    (a b))
@@ -1665,9 +1622,16 @@
 ;;;   Return the float epsilon value for the given float type.
 (defmethod epsilon ((x cl:float))
   (etypecase x
+    ;; The main purpose of the #+ read-time conditionals is to prevent
+    ;; compiler warnings on Lisp implementations that don't have distinct types
+    ;; for all floating point types defined by Common Lisp.
+;;    #+has-distinct-short-float
     (short-float short-float-epsilon)
+;;    #+has-distinct-single-float
     (single-float single-float-epsilon)
+;;    #+has-distinct-double-float
     (double-float double-float-epsilon)
+;;    #+has-distinct-long-float
     (long-float long-float-epsilon)))
 
 (defmethod epsilon ((x cl:complex))
@@ -1768,23 +1732,6 @@
 	    (third r)
 	    (bigfloat (signum (second r))))))
 
-;; GCL doesn't have a REAL class!
-#+gcl
-(progn
-(defmethod float ((x cl:float) (y cl:float))
-  (cl:float x y))
-
-(defmethod float ((x cl:rational) (y cl:float))
-  (cl:float x y))
-
-(defmethod float ((x cl:float) (y bigfloat))
-  (bigfloat x))
-
-(defmethod float ((x cl:rational) (y bigfloat))
-  (bigfloat x))
-)
-
-#-gcl
 (progn
 (defmethod float ((x real) (y cl:float))
   (cl:float x y))
@@ -1869,37 +1816,18 @@
   (let ((r (slot-value x 'real)))
     (third (first r))))
 
-#-gcl
 (defmethod rational ((x real))
   (cl:rational x))
 
-#+gcl
-(progn
-(defmethod rational ((x cl:float))
-  (cl:rational x))
-(defmethod rational ((x cl:rational))
-  (cl:rational x))
-)
-
 (defmethod rational ((x bigfloat))
   (destructuring-bind ((marker simp prec) mantissa exp)
       (real-value x)
     (declare (ignore marker simp))
     (* mantissa (expt 2 (- exp prec)))))
 
-#-gcl
 (defmethod rationalize ((x real))
   (cl:rationalize x))
 
-#+gcl
-(progn
-(defmethod rationalize ((x cl:float))
-  (cl:rationalize x))
-(defmethod rationalize ((x cl:rational))
-  (cl:rationalize x))
-)
-
-
 ;;; This routine taken from CMUCL, which, in turn is a routine from
 ;;; CLISP, which is GPL.
 ;;;
@@ -1926,7 +1854,7 @@
 ;;;       the choice of a. Therefore we can simply ignore this case.
 ;;;     Note 2: At first, we need to consider the closed interval [a,b].
 ;;;       but since a and b have the denominator 2^(|e|+1) whereas x itself
-;;;       has a denominator <= 2^|e|, we can restrict the seach to the open
+;;;       has a denominator <= 2^|e|, we can restrict the search to the open
 ;;;       interval (a,b).
 ;;;     So, for given a and b (0 < a < b) we are searching a rational number
 ;;;     y with a <= y <= b.
@@ -2065,21 +1993,18 @@
 ;;;   Return a value of pi with the same precision as the argument.
 ;;; For rationals, we return a single-float approximation.
 (defmethod %pi ((x cl:rational))
-  (declare (ignore x))
   (cl:coerce cl:pi 'single-float))
 
 (defmethod %pi ((x cl:float))
   (cl:float cl:pi x))
 
 (defmethod %pi ((x bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fppi))))
 
 (defmethod %pi ((x cl:complex))
   (cl:float cl:pi (realpart x)))
 
 (defmethod %pi ((x complex-bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fppi))))
 
 ;;; %e - External
@@ -2087,21 +2012,18 @@
 ;;;   Return a value of e with the same precision as the argument.
 ;;;   For rationals, we return a single-float approximation.
 (defmethod %e ((x cl:rational))
-  (declare (ignore x))
   (cl:coerce maxima::%e-val 'single-float))
 
 (defmethod %e ((x cl:float))
   (cl:float maxima::%e-val x))
 
 (defmethod %e ((x bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fpe))))
 
 (defmethod %e ((x cl:complex))
   (cl:float maxima::%e-val (realpart x)))
 
 (defmethod %e ((x complex-bigfloat))
-  (declare (ignore x))
   (to (maxima::bcons (maxima::fpe))))
 
 ;;;; Useful routines
@@ -2205,3 +2127,238 @@
 	  sum)
       #+nil
       (format t "~4d: ~S ~S ~S~%" k sum term (funcall f k)))))
+
+;; Format bigfloats using ~E format. This is suitable as a ~// format.
+;;
+;; NOTE: This is a modified version of FORMAT-EXPONENTIAL from CMUCL to
+;; support printing of bfloats.
+
+(defun format-e (stream number colonp atp
+		 &optional w d e k
+		   overflowchar padchar exponentchar)
+  (typecase number
+    (bigfloat
+     (maxima::bfloat-format-e stream (real-value number) colonp atp
+			      w d e (or k 1)
+			      overflowchar
+			      (or padchar #\space)
+			      (or exponentchar #\b)))
+    (complex-bigfloat
+     ;; FIXME: Do something better than this since this doesn't honor
+     ;; any of the parameters.
+     (princ number stream))
+    (otherwise
+     ;; We were given some other kind of object. Just use CL's normal
+     ;; ~E printer to print it.
+     (let ((f
+	     (with-output-to-string (s)
+	       ;; Construct a suitable ~E format string from the given
+	       ;; parameters. First, handle w,d,e,k.
+	       (write-string "~V,V,V,V," s)
+	       (if overflowchar
+		   (format s "'~C," overflowchar)
+		   (write-string "," s))
+	       (if padchar
+		   (format s "'~C," padchar)
+		   (write-string "," s))
+	       (when exponentchar
+		 (format s "'~C" exponentchar))
+	       (when colonp
+		 (write-char #\: s))
+	       (when atp
+		 (write-char #\@ s))
+	       (write-char #\E s))))
+       (format stream f w d e k number)))))
+
+#|
+(defmacro assert-equal (expected form)
+  (let ((result (gensym))
+	(e (gensym)))
+    `(let ((,e ,expected)
+	  (,result ,form))
+       (unless (equal ,e ,result)
+	 (format *debug-io* "Assertion failed: Expected ~S but got ~S~%" ,e ,result)))))
+
+(assert-equal "  0.990E+00" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 99/100)))
+(assert-equal "  0.999E+00" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 999/1000)))
+;; Actually "  0.100E+01", but format-e doesn't round the output.
+(assert-equal "  0.999E+00" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 9999/10000)))
+(assert-equal "  0.999E-04" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 0000999/10000000)))
+;; Actually "  0.100E-03", but format-e doesn't round the output.
+(assert-equal "  0.999E-0e" (format nil
+				    "~11,3,2,0,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 00009999/100000000)))
+(assert-equal "  9.999E-05" (format nil
+				    "~11,3,2,,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 00009999/100000000)))
+;; Actually "  1.000E-04", but format-e doesn't round the output.
+(assert-equal "  9.999E-05" (format nil
+				    "~11,3,2,,'*,,'E/bigfloat::format-e/"
+				    (bigfloat:bigfloat 000099999/1000000000)))
+;; All of these currently fail.
+(assert-equal ".00123d+6" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat 1.2345689d3)))
+(assert-equal "-.0012d+6" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat -1.2345689d3)))
+(assert-equal ".00123d+0" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat 1.2345689d-3)))
+(assert-equal "-.0012d+0" (format nil
+				  "~9,,,-2/bigfloat::format-e/"
+				  (bigfloat:bigfloat -1.2345689d-3)))
+
+;; These fail because too many digits are printed and because the
+;; scale factor isn't properly applied.
+(assert-equal ".00000003d+8" (format nil
+				     "~9,4,,-7E"
+				     (bigfloat:bigfloat pi)))
+(assert-equal ".000003d+6" (format nil
+				   "~9,4,,-5E"
+				   (bigfloat:bigfloat pi)))
+(assert-equal "3141600.d-6" (format nil
+				    "~5,4,,7E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal "  314.16d-2" (format nil
+				    "~11,4,,3E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal "  31416.d-4" (format nil
+				    "~11,4,,5E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal "  0.3142d+1" (format nil
+				    "~11,4,,0E"
+				    (bigfloat:bigfloat pi)))
+(assert-equal ".03142d+2" (format nil
+				  "~9,,,-1E"
+				  (bigfloat:bigfloat pi)))
+(assert-equal "0.003141592653589793d+3" (format nil
+						"~,,,-2E"
+						(bigfloat:bigfloat pi)))
+(assert-equal "31.41592653589793d-1" (format nil
+					     "~,,,2E"
+					     (bigfloat:bigfloat pi)))
+;; Fails because exponent is printed as "b0" instead of "b+0"
+(assert-equal "3.141592653589793b+0" (format nil "~E" (bigfloat:bigfloat pi)))
+
+
+;; These fail because too many digits are printed and because the
+;; scale factor isn't properly applied.
+(assert-equal ".03142d+2" (format nil "~9,5,,-1E" (bigfloat:bigfloat pi)))
+(assert-equal " 0.03142d+2" (format nil "~11,5,,-1E" (bigfloat:bigfloat pi)))
+(assert-equal "| 3141593.d-06|" (format nil "|~13,6,2,7E|" (bigfloat:bigfloat pi)))
+(assert-equal "0.314d+01" (format nil "~9,3,2,0,'%E" (bigfloat:bigfloat pi)))
+(assert-equal "+.003d+03" (format nil "~9,3,2,-2,'%@E" (bigfloat:bigfloat pi)))
+(assert-equal "+0.003d+03" (format nil "~10,3,2,-2,'%@E" (bigfloat:bigfloat pi)))
+(assert-equal "=====+0.003d+03" (format nil "~15,3,2,-2,'%,'=@E" (bigfloat:bigfloat pi)))
+(assert-equal "0.003d+03" (format nil "~9,3,2,-2,'%E" (bigfloat:bigfloat pi)))
+(assert-equal "%%%%%%%%" (format nil "~8,3,2,-2,'%@E" (bigfloat:bigfloat pi)))
+
+;; Works
+(assert-equal "0.0f+0" (format nil "~e" 0))
+
+;; Fails because exponent is printed as "b0" instead of "b+0'
+(assert-equal "0.0b+0" (format nil "~e" (bigfloat:bigfloat 0d0)))
+;; Fails because exponent is printed as "b0   " instead of "b+0000"
+(assert-equal "0.0b+0000" (format nil "~9,,4e" (bigfloat:bigfloat 0d0)))
+;; Fails because exponent is printed as "b4" instead of "b+4"
+(assert-equal "1.2345678901234567b+4" (format nil "~E"
+					      (bigfloat:bigfloat 1.234567890123456789d4)))
+  
+;; Fails because exponent is printed as "b36" instead of "b+36"
+(assert-equal "1.32922799578492b+36" (format nil "~20E"
+					     (bigfloat:bigfloat (expt 2d0 120))))
+;; Fails because too many digits are printed and the exponent doesn't include "+".
+(assert-equal "       1.32922800b+36" (format nil "~21,8E"
+					      (bigfloat:bigfloat (expt 2d0 120))))
+|#
+
+
+;; Format bigfloats using ~F format. This is suitable as a ~// format.
+;;
+;; NOTE: This is a modified version of FORMAT-FIXED from CMUCL to
+;; support printing of bfloats.
+
+(defun format-f (stream number colonp atp
+		 &optional w d k overflowchar padchar)
+  (typecase number
+    (bigfloat
+     (maxima::bfloat-format-f stream (real-value number) colonp atp
+			      w d (or k 0)
+			      overflowchar
+			      (or padchar #\space)))
+    (complex-bigfloat
+     ;; FIXME: Do something better than this since this doesn't honor
+     ;; any of the parameters.
+     (princ number stream))
+    (otherwise
+     ;; We were given some other kind of object. Just use CL's normal
+     ;; ~F printer to print it.
+     (let ((f
+	     (with-output-to-string (s)
+	       ;; Construct a suitable ~F format string from the given
+	       ;; parameters.  First handle w,d,k.
+	       (write-string "~V,V,V," s)
+	       (if overflowchar
+		   (format s "'~C," overflowchar)
+		   (write-string "," s))
+	       (if (char= padchar #\space)
+		   (write-string "," s)
+		   (format s "'~C," padchar))
+	       (when colonp
+		 (write-char #\: s))
+	       (when atp
+		 (write-char #\@ s))
+	       (write-char #\F s))))
+       (format stream f w d k number)))))
+
+;; Format bigfloats using ~G format. This is suitable as a ~// format.
+;;
+;; NOTE: This is a modified version of FORMAT-GENERAL from CMUCL to
+;; support printing of bfloats.
+
+(defun format-g (stream number colonp atp
+		 &optional w d e k overflowchar padchar marker)
+  (typecase number
+    (bigfloat
+     (maxima::bfloat-format-g stream (real-value number) colonp atp
+			      w d e (or k 1) 
+			      overflowchar
+			      (or padchar #\space)
+			      (or marker #\b)))
+    (complex-bigfloat
+     ;; FIXME: Do something better than this since this doesn't honor
+     ;; any of the parameters.
+     (princ number stream))
+    (otherwise
+     ;; We were given some other kind of object. Just use CL's normal
+     ;; ~G printer to print it.
+     (let ((f
+	     (with-output-to-string (s)
+	       ;; Construct a suitable ~E format string from the given
+	       ;; parameters. First, handle w,d,e,k.
+	       (write-string "~V,V,V,V," s)
+	       (if overflowchar
+		   (format s "'~C," overflowchar)
+		   (write-string "," s))
+	       (if padchar
+		   (format s "'~C," padchar)
+		   (write-string "," s))
+	       (when marker
+		 (format s "'~C" marker))
+	       (when colonp
+		 (write-char #\: s))
+	       (when atp
+		 (write-char #\@ s))
+	       (write-char #\G s))))
+       (format stream f w d e k number)))))
+     
+     
