@@ -1,5 +1,13 @@
-;;; Compiled by f2cl version 2.0 beta Date: 2007/05/04 17:29:50 
-;;; Using Lisp CMU Common Lisp Snapshot 2007-05 (19D)
+;;; Compiled by f2cl version:
+;;; ("f2cl1.l,v 46c1f6a93b0d 2012/05/03 04:40:28 toy $"
+;;;  "f2cl2.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl3.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl4.l,v 96616d88fb7e 2008/02/22 22:19:34 rtoy $"
+;;;  "f2cl5.l,v 46c1f6a93b0d 2012/05/03 04:40:28 toy $"
+;;;  "f2cl6.l,v 1d5cbacbb977 2008/08/24 00:56:27 rtoy $"
+;;;  "macros.l,v fceac530ef0c 2011/11/26 04:02:26 toy $")
+
+;;; Using Lisp CMU Common Lisp snapshot-2012-04 (20C Unicode)
 ;;; 
 ;;; Options: ((:prune-labels nil) (:auto-save t) (:relaxed-array-decls t)
 ;;;           (:coerce-assigns :as-needed) (:array-type ':simple-array)
@@ -15,22 +23,24 @@
                    :initial-contents '(0 2 0 10 1 0 0 0 0))))
   (declare (type (simple-array f2cl-lib:integer4 (9)) iparam))
   (defun j4save (iwhich ivalue iset)
-    (declare (type f2cl-lib:logical iset) (type (integer) ivalue iwhich))
+    (declare (type f2cl-lib:logical iset)
+             (type (f2cl-lib:integer4) ivalue iwhich))
     (prog ((j4save 0))
-      (declare (type (integer) j4save))
+      (declare (type (f2cl-lib:integer4) j4save))
       (setf j4save (f2cl-lib:fref iparam (iwhich) ((1 9))))
       (if iset (setf (f2cl-lib:fref iparam (iwhich) ((1 9))) ivalue))
       (go end_label)
      end_label
       (return (values j4save nil nil nil)))))
 
-(in-package #-gcl #:cl-user #+gcl "CL-USER")
+(in-package #:cl-user)
 #+#.(cl:if (cl:find-package '#:f2cl) '(and) '(or))
 (eval-when (:load-toplevel :compile-toplevel :execute)
   (setf (gethash 'fortran-to-lisp::j4save
                  fortran-to-lisp::*f2cl-function-info*)
           (fortran-to-lisp::make-f2cl-finfo
-           :arg-types '((integer) (integer) fortran-to-lisp::logical)
+           :arg-types '((fortran-to-lisp::integer4) (fortran-to-lisp::integer4)
+                        fortran-to-lisp::logical)
            :return-values '(nil nil nil)
            :calls 'nil)))
 
