@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -19,10 +19,14 @@
 (macsyma-module outmis)
 
 
-(declare-top (special $exptisolate $labels $dispflag errorsw))
+(declare-top (special $exptisolate))
 
-(defmvar $exptisolate nil)
-(defmvar $isolate_wrt_times nil)
+(defmvar $exptisolate nil
+  nil
+  :properties ((evflag t)))
+(defmvar $isolate_wrt_times nil
+  nil
+  :properties ((evflag t)))
 
 (defmfun $isolate (e *xvar)
   (iso1 e (getopr *xvar)))
@@ -119,9 +123,6 @@
 		   ((eq (caar e) 'mplus) (cons u (nreverse v)))
 		   (t (cons u v)))))))
 
-(declare-top (special atvars munbound $props $gradefs $features opers
-		      $contexts $activecontexts $aliases))
-
 (defmspec $properties (x)
   (setq x (getopr (fexprcheck x)))
   (unless (or (symbolp x) (stringp x))
@@ -150,6 +151,8 @@
   	       (if (fboundp x) (nconc l (list "system function")))))
 	 l)
 
+     ;; Only process properties with non-NIL values.
+     (when (cadr y)
       ;; TOP-LEVEL PROPERTIES
       (cond ((setq prop 
                    (assoc (car y)
@@ -172,7 +175,7 @@
   	   (nconc l (ncons (cdr prop))))
   	  ((setq prop (member (car y) opers :test #'eq)) 
   	   (nconc l (list (car prop))))
-  	  ((and (eq (car y) 'operators) (not (eq (cadr y) 'simpargs1)))
+  	  ((and (eq (car y) 'operators) (not (or (eq (cadr y) 'simpargs1) (eq (cadr y) nil))))
   	   (nconc l (list '$rule)))
   	  ((and (member (car y) '(fexpr fsubr mfexpr*s mfexpr*) :test #'eq)
   		(nconc l (ncons "special evaluation form"))
@@ -225,7 +228,7 @@
   			   (do ((y (cdadr y) (cddr y))
   				(l (list '(mlist) "user properties")))
   			       ((null y) (list l))
-  			     (nconc l (list (car y)))))))))))))
+  			     (nconc l (list (car y))))))))))))))
 
 (defmspec $propvars (x)
   (setq x (fexprcheck x))
@@ -313,13 +316,13 @@
 (defun dispmatchdeclares (l)
   (do ((i l (cdr i))
        (ret))
-      ((null i) (cons '(mlist) ret))
+      ((null i) (cons '(mlist) (reverse ret)))
     (setq l (car (mget (car i) 'matchdeclare)))
-    (setq ret (cons (append (cond ((atom l) (ncons (ncons l))) (t l))
+    (setq ret (cons (append (cond ((atom l) (ncons (ncons l))) ((eq (caar l) 'lambda) (list '(mqapply) l))  (t l))
 			    (ncons (car i)))
 		    ret))))
 
-(declare-top (special $programmode *roots *failures varlist genvar $ratfac))
+(declare-top (special *roots *failures))
 
 (defmfun $changevar (expr trans nvar ovar)
   (let ($ratfac)
@@ -391,8 +394,8 @@
 					     trans ovar)))))
 	     (cond
 	       (nfun
-		;; nfun is basically the result of subtituting ovar
-		;; with tfun in the integratand (summand).
+		;; nfun is basically the result of substituting ovar
+		;; with tfun in the integrand (summand).
 		(cond	
 		  ((cdddr expr)
 		   ;; Handle definite integral, summation, or product.
@@ -432,7 +435,7 @@
 		     varlist nvarlist)
 	    (rdis (cdr expr))))))
 
-(declare-top (special $listconstvars facfun))
+(declare-top (special facfun))
 
 (defmfun $factorsum (e)
   (factorsum0 e '$factor))
