@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -89,7 +89,7 @@
 
 ;;; THIS TELLS THE EVALUATOR TO KEEP OUT OF POISSON $SERIES.
 
-(defprop mpois (lambda (x) x) mfexpr*)
+(defmspec mpois (x) x)
 
 (defmfun $poisplus (a b)
   (setq a (intopois a) b (intopois b))
@@ -176,11 +176,13 @@
 
 (defun poisencode (h*)
   (unless (checkencode h*)
-    (merror "Illegal arg to `poissimp':~%~M" h*))
+    ;; NOT CLEAR WHAT IS ILLEGAL HERE
+    (merror (intl:gettext "poissimp: illegal argument: ~M") h*))
   (apply #'(lambda ($z $y $x $w $v $u)
 	     (declare (special $u $v $w $x $y $z))
 	     (setq h* (meval h*))
-	     (unless (integerp h*) (merror  "Illegal trig arg to `poisson' form"))
+	     ;; NOT CLEAR WHAT IS ILLEGAL HERE EITHER
+	     (unless (integerp h*) (merror  (intl:gettext "poisson: illegal trigonometric argument.")))
 	     (+ poishift  h*))
 	 poisvals))
 
@@ -270,7 +272,8 @@
 				(poiscdecode (cadr m))
 				(list '(%sin) (poisdecodec (car m))))
 			  t))
-       (terpri))
+       (terpri)
+       (finish-output))
 
      ;; DO COSINES
      (do ((m
@@ -282,7 +285,8 @@
 				(cond ((equal (car m) poishift) 1.)
 				      (t (list '(%cos) (poisdecodec (car m))))))
 			  t))
-       (terpri))
+       (terpri)
+       (finish-output))
      (return '$done)))
 
 
@@ -318,7 +322,7 @@
 (defun poisxcoef (h m)
   (- (rem (quotient h
 		    (expt poists
-			  (cadr (member m '($u 0 $v 1 $w 2 $x 3 $y 4 $z 5) :test #'eq))))
+			  (cadr (member m '($u 0 $v 1 $w 2 $x 3 $y 4 $z 5)))))
 	  poists)
      poistsm))
 
