@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -20,16 +20,8 @@
 
 (load-macsyma-macros rzmac)
 
-(declare-top (special $%emode $radexpand rp-polylogp $domain $m1pbranch
-		      $logarc rischp $keepfloat complexsign))
-
-(defmvar implicit-real nil "If t RPART assumes radicals and logs
-	 of real quantities are real and doesn't ask sign questions")
-
-(defmvar generate-atan2 t "Controls whether RPART will generate ATAN's
-			or ATAN2's, default is to make ATAN2's")
-;; generate-atan2 is set to nil when doing integration to avoid
-;; generating discontinuities that defint can't handle.
+(declare-top (special $radexpand
+		      $keepfloat))
 
 ;;; Realpart gives the real part of an expr.
 
@@ -39,6 +31,17 @@
 (defprop %realpart $realpart noun)
 (defprop %realpart simp-realpart operators)
 
+(defun risplit-signum (x) ;rectangular form for a signum expression
+  (let*  ((z (risplit (cadr x))) (a (car z)) (b (cdr z)) (r)) ;signum(a+%i b), where a and b are real
+    (cond ((eq t (meqp b 0)) ;signum(a) -> signum(a) + 0 %i
+	   (cons (take '(%signum) a) 0))
+	  ((or (eq t (mnqp a 0)) (eq t (mnqp b 0))) ;signum(a + %i b) --> a/sqrt(a^2+b^2) + %i b/sqrt(a^2+b^2)
+	   (setq r (take '(%sqrt) (add (power a 2) (power b 2))))
+	   (cons (div a r) (div b r)))
+	  (t (cons (take '(%realpart) x) (take '(%imagpart) x)))))) ;nothing known
+
+(setf (get '%signum 'risplit-function) 'risplit-signum)
+
 (defun simp-realpart (expr z simpflag)
   (oneargcheck expr)
   (setq z (simpcheck (cadr expr) simpflag))
@@ -79,14 +82,14 @@
 
 ;;; Rectform gives a result of the form a+b*%i.
 
-(defmfun $rectform (xx)
+(defmfun ($rectform :properties ((evfun t))) (xx)
   (let ((ris (trisplit xx)))
     (add (car ris) (mul (cdr ris) '$%i))))
 
 ;;; Polarform gives a result of the form a*%e^(%i*b).
 
-(defmfun $polarform (xx)
-  (cond ((and (not (atom xx)) (member (caar xx) '(mequal mlist $matrix) :test #'eq))
+(defmfun ($polarform :properties ((evfun t))) (xx)
+  (cond ((mbagp xx)
 	 (cons (car xx) (mapcar #'$polarform (cdr xx))))
 	(t
 	 (let ((aas (absarg xx)) ($%emode nil))
@@ -123,8 +126,7 @@
 ;;; Carg gives the complex argument.
 
 (defmfun $carg (xx)
-  (cond ((and (not (atom xx)) 
-              (member (caar xx) '(mequal mlist $matrix) :test #'eq))
+  (cond ((mbagp xx)
 	 (cons (car xx) (mapcar #'$carg (cdr xx))))
 	(t (cdr (absarg xx)))))
 
@@ -151,7 +153,7 @@
            (eqtest (list '(%carg) z) expr)))))
 
 ;; The internal cabs, used by other Macsyma programs.
-(defmfun cabs (xx) (car (absarg xx t)))
+(defun cabs (xx) (car (absarg xx t)))
 
 ;; Some objects can only appear at the top level of a legal simplified
 ;; expression: CRE forms and equations in particular.
@@ -230,115 +232,144 @@
 	     (psetq rpart (sub (mul rpart (caar m)) (mul ipart (cdar m)))
 		    ipart (add (mul ipart (caar m)) (mul rpart (cdar m)))))))))
 
+;; Split L = ((mexpt) BASE POW) into real and imaginary parts.
 (defun risplit-expt (l)
-  (let ((pow (caddr l))
-	($radexpand nil)
-	(ris nil))		   ; Don't want 'simplifications' like
-    (cond ((fixnump pow)	   ; Sqrt(-x) -> %i*sqrt(x)
-	   (let ((sp (risplit (cadr l))))
-	     (cond ((= pow -1)
-		    ;; Handle the case of 1/(x+%i*y) carefully.  This
-		    ;; is needed if x and y are (Lisp) numbers to
-		    ;; prevent spurious underflows/overflows.  See Bug
-		    ;; 2954472.
-		    ;; https://sourceforge.net/tracker/?func=detail&atid=104933&aid=2954472&group_id=4933.
-		    ;;
-		    (if (and (or (numberp (car sp))
-				 (ratnump (car sp)))
-			     (or (numberp (cdr sp))
-				 (ratnump (cdr sp))))
-			(sprecip sp)
-			(let ((a2+b2 (spabs sp)))
-			  (cons (div (car sp) a2+b2)
-				(mul -1 (div (cdr sp) a2+b2))))))
-		   ((> (abs pow) $maxposex)
-		    (cond ((=0 (cdr sp))
-			   (cons (powers (car sp) pow) 0))
-			  (t
-			   (let ((abs^n (powers (add (powers (car sp) 2)
-						     (powers (cdr sp) 2))
-						(*red pow 2)))
-				 (natan (mul pow (genatan (cdr sp) (car sp)))))
-			     (cons (mul abs^n (take '(%cos) natan))
-				   (mul abs^n (take '(%sin) natan)))))))
-		   ((> pow 0)
-		    (expanintexpt sp pow))
-		   (t
-		    (let ((abbas (powers (spabs sp) (- pow)))
-			  (basspli (expanintexpt sp (- pow))))
-		      (cons (div (car basspli) abbas)
-			    (neg (div (cdr basspli) abbas))))))))
-	  ((and (ratnump pow)
-		(fixnump (cadr pow))
-		(not (< (cadr pow) (- $maxnegex)))
-		(not (> (cadr pow) $maxposex))
-		(prog2
-		    (setq ris (risplit (cadr l)))
-		    (or (= (caddr pow) 2) (=0 (cdr ris)))))
-	   (cond ((=0 (cdr ris))
-		  (case (cond ((mnegp (car ris)) '$neg)
-			      (implicit-real '$pos)
-			      (t ($sign (car ris)))) ; Use $sign not asksign
-		    ($neg (risplit (mul2 (power -1 pow) 
-                                         (power (neg (car ris)) pow))))
-		    ($zero (cons (power 0 pow) 0))
-                    ($pos (cons (power (car ris) pow) 0)) ; Add the case $pos
-                    (t
-                     ;; The sign is unknown. Return a general form.
-                     (let ((sp (risplit (caddr l)))
-		           (aa (absarg1 (cadr l))))
-                       (let ((pre (mul (powers '$%e (mul (cdr aa) (mul (cdr sp) -1)))
-                                       (powers (car aa) (car sp))))
-                             (post (add (mul (cdr sp) (take '(%log) (car aa)))
-                                        (mul (car sp) (cdr aa)))))
-                       (cons (mul pre (take '(%cos) post))
-                             (mul pre (take '(%sin) post))))))))
-		 (t
-		  (let ((abs2 (spabs ris))
-			(n (abs (cadr pow)))
-			(pos? (> (cadr pow) -1)))
-		    (let ((abs (power abs2 (1//2)))
-                          (sign-imagpart ($sign (cdr ris)))) ; Do we know the sign?
-                      (cond ((member sign-imagpart '($neg $pos))
-                             (divcarcdr
-                               (expanintexpt
-                                 (cons (power (add abs (car ris)) (1//2))
-                                       (porm (let ((a pos?)
-                                                   (b (eq (asksign (cdr ris)) 
-                                                          '$negative)))
-                                               (cond (a (not b))
-                                                     (b t)))
-                                             (power (sub abs (car ris)) (1//2))))
-                                 n)
-                               (if pos?
-                                   (power 2 (div n 2))
-                                   (power (mul 2 abs2) (div n 2)))))
-                            (t
-                             ;; The sign is unknown. Return a general form.
-                             (let ((sp (risplit (caddr l)))
-                                   (aa (absarg1 (cadr l))))
-                               (let ((pre (mul (powers '$%e 
-                                                       (mul (cdr aa) 
-                                                       (mul (cdr sp) -1)))
-                                               (powers (car aa) (car sp))))
-                                     (post (add (mul (cdr sp) 
-                                                     (take '(%log) (car aa)))
-                                                (mul (car sp) (cdr aa)))))
-                                 (cons (mul pre (take '(%cos) post))
-                                       (mul pre (take '(%sin) post))))))))))))
-	  ((and (floatp (setq ris (cadr l))) (floatp pow))
-	   (risplit (let (($numer t))
-		      (exptrl ris pow))))
-	  (t
-	   (let ((sp (risplit (caddr l)))
-		 (aa (absarg1 (cadr l))))
-	     ;;If all else fails, we use the trigonometric form.
-	     (let ((pre (mul (powers '$%e (mul (cdr aa) (mul (cdr sp) -1)))
-			     (powers (car aa) (car sp))))
-		   (post (add (mul (cdr sp) (take '(%log) (car aa)))
-			      (mul (car sp) (cdr aa)))))
-	       (cons (mul pre (take '(%cos) post))
-		     (mul pre (take '(%sin) post)))))))))
+  (let* ((base (cadr l)) (pow (caddr l))
+         ;; Disable 'simplifications' like sqrt(-x) -> %i*sqrt(x)
+         ($radexpand nil)
+         (sp (risplit base)))
+    (cond
+      ((fixnump pow)
+       (risplit-expt-fixnum-pow sp pow))
+
+      ((and (ratnump pow)
+            (fixnump (cadr pow))
+            (not (< (cadr pow) (- $maxnegex)))
+            (not (> (cadr pow) $maxposex))
+            (or (= (caddr pow) 2) (=0 (cdr sp))))
+       (if (=0 (cdr sp))
+           (risplit-expt-real^rat base pow)
+           (risplit-expt-sqrt-pow base sp pow)))
+
+      ((and (floatp base) (floatp pow))
+       (risplit (let (($numer t)) (exptrl base pow))))
+
+      (t
+       (destructuring-bind (alpha . beta) (risplit pow)
+         (destructuring-bind (r . theta) (absarg1 base)
+           (risplit-expt-general-form r theta alpha beta)))))))
+
+;; Split BASE^POWER into real and imaginary parts. POWER is assumed to be a
+;; fixnum. SP is (RISPLIT BASE)
+(defun risplit-expt-fixnum-pow (sp power)
+  ;; We use the squared absolute value of BASE several times
+  ;; below. Unfortunately, we can't calculate it at the start, since that causes
+  ;; floating point under/overflows in the case mentioned in the comment
+  ;; below. Instead, we calculate it when it's needed (a maximum of once).
+  (destructuring-bind (real . imag) sp
+    (cond
+      ((= power -1)
+       ;; Handle the case of 1/(x+%i*y) carefully.  This
+       ;; is needed if x and y are (Lisp) numbers to
+       ;; prevent spurious underflows/overflows. See bug 1908.
+       (if (and (or (numberp real) (ratnump real))
+                (or (numberp imag) (ratnump imag)))
+           (sprecip sp)
+           (let ((abs2 (spabs sp)))
+             (cons (div real abs2) (mul -1 (div imag abs2))))))
+
+      ((> (abs power) $maxposex)
+       (if (=0 imag)
+           (cons (powers real power) 0)
+           (let ((abs^n (powers (spabs sp) (*red power 2)))
+                 (natan (mul power (genatan imag real))))
+             (cons (mul abs^n (take '(%cos) natan))
+                   (mul abs^n (take '(%sin) natan))))))
+
+      ((> power 0)
+       (expanintexpt sp power))
+
+      (t
+       (let ((abbas (powers (spabs sp) (- power)))
+             (basspli (expanintexpt sp (- power))))
+         (cons (div (car basspli) abbas)
+               (neg (div (cdr basspli) abbas))))))))
+
+;; Return the "general form" for RISPLIT applied to
+;; (r*exp(%i*theta))^(alpha+%i*beta), whose rectform is
+;;
+;;   pre * cos(post) + %i * pre * sin(post)
+;;
+;; where pre  = exp(-theta*beta) * r^alpha
+;; and   post = beta*log(r) + alpha*theta
+(defun risplit-expt-general-form (r theta alpha beta)
+  (let ((pre (mul (powers '$%e (mul -1 theta beta))
+                  (powers r alpha)))
+        (post (add (mul beta (take '(%log) r))
+                   (mul alpha theta))))
+    (cons (mul pre (take '(%cos) post))
+          (mul pre (take '(%sin) post)))))
+
+;; Split BASE^POWER into real and imaginary parts. We assume that BASE is real
+;; and that POWER is a rational number.
+(defun risplit-expt-real^rat (base power)
+  (case (cond ((mnegp base) '$neg)
+              (implicit-real '$pos)
+              (t ($sign base)))    ; Use $sign not asksign
+    ($neg (risplit (mul2 (power -1 power) (power (neg base) power))))
+    ($zero (cons (power 0 power) 0))
+    ($pos (cons (power base power) 0))
+    (t
+     (destructuring-bind (r . theta) (absarg1 base)
+       (risplit-expt-general-form r theta power 0)))))
+
+;; Split BASE^POWER into real and imaginary parts. SP is (RISPLIT BASE). We
+;; assume that POWER is a rational number. Moreover, we assume that the
+;; denominator of POWER is 2.
+(defun risplit-expt-sqrt-pow (base sp power)
+  ;; n = abs(2*power) is a non-negative integer
+  (destructuring-bind (real . imag) sp
+    (let* ((abs2 (spabs sp)) (abs (power abs2 1//2))
+           (n (abs (cadr power)))
+           (pos? (> (cadr power) -1))
+           (imag-sign ($sign imag)))
+      (cond
+        ((member imag-sign '($neg $pos))
+         ;; Here, we use the half-angle formulas for cos and sin. Assuming we
+         ;; are always taking the "principal square root" (that with argument
+         ;; less than equal to the argument of base), these come out as
+         ;;
+         ;;   cos(arg/2) = +- sqrt((1+real/abs)/2)
+         ;;   sin(arg/2) = +- sqrt((1-real/abs)/2)
+         ;;
+         ;; We know that real+%i*imag = abs*exp(%i*arg). Taking square roots,
+         ;; you get that
+         ;;
+         ;;   sqrt(real+%i*imag) = sqrt(abs)*exp(%i*arg/2).
+         ;;                      = sqrt(abs)*cos(arg/2) +
+         ;;                           %i * sqrt(abs)*sin(arg/2)
+         ;;                      = (sqrt(abs+real) + %i*sqrt(abs-real))/sqrt(2)
+         ;;
+         ;; but possibly with signs on the square roots. This function always
+         ;; chooses the square root with the non-negative real part. As such, we
+         ;; have to switch the sign of the sine term when we are raising to a
+         ;; positive power and imag < 0 or if raising to a negative power and
+         ;; imag > 0. To see that the first argument of the PORM call below is
+         ;; correct, write out the 2x2 truth table...
+         (divcarcdr
+          (expanintexpt
+           (cons (power (add abs real) 1//2)
+                 (porm (eq (eq imag-sign '$pos) pos?)
+                       (power (sub abs real) 1//2)))
+           n)
+          (if pos?
+              (power 2 (div n 2))
+              (power (mul 2 abs2) (div n 2)))))
+
+        (t
+         (destructuring-bind (alpha . beta) (risplit power)
+           (destructuring-bind (r . theta) (absarg1 base)
+             (risplit-expt-general-form r theta alpha beta))))))))
 
 (defun risplit-noun (l)
   (cons (simplify (list '(%realpart) l)) (simplify (list '(%imagpart) l))))
@@ -365,9 +396,12 @@
 (defun risplit (l)
   (let (($domain '$complex) ($m1pbranch t) $logarc op)
     (cond ((atom l)
+           ;; Symbols are assumed to represent real values, unless they have
+           ;; been declared to be complex. If they have been declared to be both
+           ;; real and complex, they are taken to be real.
 	   (cond ((eq l '$%i) (cons 0 1))
 		 ((eq l '$infinity) (cons '$und '$und))
-		 ((decl-complexp l) (risplit-noun l))
+		 ((and (decl-complexp l) (not (decl-realp l))) (risplit-noun l))
 		 (t (cons l 0))))
 	  ((eq (caar l) 'rat) (cons l 0))
 	  ((eq (caar l) 'mplus) (risplit-mplus l))
@@ -421,15 +455,20 @@
 	  ((and (member (caar l) '(%atan %csc %sec %cot %csch %sech %coth) :test #'eq)
 		(=0 (cdr (risplit (cadr l)))))
 	   (cons l 0))
-          ((and (eq (caar l) '$atan2)
+          ((and (eq (caar l) '%atan2)
                 (not (zerop1 (caddr l)))
                 (=0 (cdr (risplit (div (cadr l) (caddr l))))))
            ;; Case atan2(y,x) and y/x a real expression.
            (cons l 0))
-	  ((or (arcp (caar l)) (eq (caar l) '$atan2))
-	   (let ((ans (risplit (let (($logarc t))
-				 (resimplify l)))))
-	     (when (eq (caar l) '$atan2)
+	  ((or (arcp (caar l)) (eq (caar l) '%atan2))
+	   (let ((ans (risplit (logarc (caar l)
+				       ;; atan2 has 2 args, unlike all
+				       ;; the other inverse trig
+				       ;; functions.
+				       (if (eq (caar l) '%atan2)
+					   (rest l)
+					   (cadr l))))))
+	     (when (eq (caar l) '%atan2)
 	       (setq ans (cons (sratsimp (car ans)) (sratsimp (cdr ans)))))
 	     (if (and (free l '$%i) (=0 (cdr ans)))
 		 (cons l 0)
@@ -437,12 +476,6 @@
 	  ((eq (caar l) '%plog)
 	   ;;  (princ '|Warning: Principal value not guaranteed for Plog in Rectform/|)
 	   (risplit (cons '(%log) (cdr l))))
-	  ((member (caar l) '(%realpart %imagpart mabs) :test #'eq) (cons l 0))
-	  ((eq (caar l) '%erf)
-	   (let ((ris (risplit (cadr l))) orig cc)
-	     (setq orig (simplify (list '(%erf) (add (car ris) (mul '$%i (cdr ris))))))
-	     (setq cc (simplify (list '(%erf) (sub (car ris) (mul '$%i (cdr ris))))))
-	     (cons (div (add orig cc) 2) (div (sub orig cc) (mul 2 '$%i)))))
 	  ;; Look for a risplit-function on the property list to handle the
 	  ;; realpart and imagpart for this function.
           ((setq op (safe-get (mop l) 'risplit-function))
@@ -452,10 +485,6 @@
 	  ((eq (caar l) 'mlist) (dsrl l))
 	  ((eq (caar l) '$matrix)
 	   (dot--ri (mapcar #'dsrl (cdr l)) '($matrix simp)))
-	  ((member (caar l) '(mlessp mleqp mgreaterp mgeqp) :test #'eq)
-	   (let ((ris1 (risplit (cadr l))) (ris2 (risplit (caddr l))))
-	     (cons (simplify (list (ncons (caar l)) (car ris1) (car ris2)))
-		   (simplify (list (ncons (caar l)) (cdr ris1) (cdr ris2))))))
 ;;;The Coversinemyfoot clause covers functions which can be converted
 ;;; to functions known by risplit, such as the more useless trigonometrics.
 	  ((let ((foot (coversinemyfoot l)))
@@ -464,14 +493,17 @@
                (decl-realp (mop l)))
            ;; Simplification for a real-valued function
            (cons l 0))
-          ((or (safe-get (mop l) 'commutes-with-conjugate)
-               (safe-get (mop l) 'conjugate-function))
-	   ;; A function with Mirror symmetry. The general expressions for
-	   ;; the realpart and imagpart simplifies accordingly.
-	   (cons (mul (div 1 2)
-		      (add (simplify (list '($conjugate) l)) l))
-		 (mul (div 1 2) '$%i
-		      (sub (simplify (list '($conjugate) l)) l))))
+      ((and (or (safe-get (mop l) 'commutes-with-conjugate)
+                (safe-get (mop l) 'conjugate-function))
+       ;; An operator that $conjugate may be able to simplify.
+       ;; If $conjugate simplifies l to something not involving '$conjugate,
+       ;; use Re(z) = (conjugate(z) + z) / 2, Im(z) = %i * (conjugate(z) - z) / 2.
+       ;; Possible improvement: Ignore instances of '$conjugate already occurring
+       ;; in the original expression l.
+       (let* ((conjugate (ftake '$conjugate l)))
+         (when (freeof '$conjugate conjugate)
+           (cons (mul (div 1 2) (add conjugate l))
+                 (mul (div 1 2) '$%i (sub conjugate l)))))))
 ;;; A MAJOR ASSUMPTION:
 ;;;  All random functions are pure real, regardless of argument.
 ;;;  This is evidently assumed by some of the integration functions.
@@ -647,6 +679,8 @@
 ;; x or -x if the sign of x must be known for some other reason.  These
 ;; techniques, however, are not perfect.
 
+(defmacro half () ''((rat simp) 1 2))  ;1/2
+
 (defun absarg (l &optional (absflag nil))
 ;; Commenting out the the expansion of the expression l. It seems to be not
 ;; necessary, but can cause expression swelling (DK 01/2010).
@@ -673,8 +707,11 @@
 			 (cons (neg l) (simplify '$%pi)))
 			(t (cons (take '(mabs) l) (genatan 0 l))))))))
 	((eq '$zero (let ((sign-imag-errp nil)) (catch 'sign-imag-err ($sign l))))
-	 (setq l ($expand l))
-	 (cons l l))
+	 (cond ((some-bfloatp l)
+		(cons bigfloatzero bigfloatzero))	; contagious
+	       ((some-floatp l)
+		(cons 0.0 0.0))
+	       (t (cons 0 0))))
 	((member (caar l) '(rat bigfloat) :test #'eq)
 	 (cons (list (car l) (abs (cadr l)) (caddr l))
 	       (argnum (cadr l))))
@@ -706,7 +743,7 @@
                     (cons (mul (power (car aa) (car sp))
                                (power '$%e (neg (mul (cdr aa) (cdr sp)))))
                           (if generate-atan2
-			      (take '($atan2)
+			      (take '(%atan2)
 				    (take '(%sin) arg)
 				    (take '(%cos) arg))
 			    (take '(%atan) (take '(%tan) arg)))))))))
@@ -744,10 +781,10 @@
 			     (half)))))))))
 
 (defun genatan (num den)
-  (let ((arg (take '($atan2) num den)))
+  (let ((arg (take '(%atan2) num den)))
     (if (or generate-atan2
             (zerop1 den)
-            (free arg '$atan2))
+            (free arg '%atan2))
         arg
         (take '(%atan) (div num den)))))
 
