@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -16,8 +16,7 @@
 
 (macsyma-module spgcd)
 
-(declare-top (special modulus temp genvar *alpha *which-factor*
-		      $algebraic algfac* $gcd))
+(declare-top (special *which-factor*))
 
 (load-macsyma-macros ratmac)
 
@@ -103,7 +102,7 @@
     (setf (aref mat row i) (ctimes (aref mat row i) c))))
 
 ;; FILL-ROW is given a point and the value of the skeleton at the point and
-;; fills the apropriate row in the matrix. with the values of the monomials
+;; fills the appropriate row in the matrix. with the values of the monomials
 ;; n is the length of the skeleton
 
 (defun fill-row (skel mat n row pt val)
