@@ -1,6 +1,6 @@
 ;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;;     The data in this file contains enhancments.                    ;;;;;
+;;;     The data in this file contains enhancements.                   ;;;;;
 ;;;                                                                    ;;;;;
 ;;;  Copyright (c) 1984,1987 by William Schelter,University of Texas   ;;;;;
 ;;;     All rights reserved                                            ;;;;;
@@ -29,11 +29,7 @@
 	(t `($any . (*mminus ,(cdr form))))))
 
 (def%tr mplus (form)
-  (let   (args mode)
-    (do ((l (cdr form) (cdr l))) ((null l))
-      (setq args (cons (translate (car l)) args)
-	    mode (*union-mode (car (car args)) mode)))
-    (setq args (nreverse args))
+  (destructuring-bind (mode . args) (translate-args/union-mode (cdr form))
     (cond ((eq '$fixnum mode) `($fixnum + . ,(mapcar #'cdr args)))
 	  ((eq '$float mode) `($float + . ,(mapcar #'dconv-$float args)))
 	  ((eq '$rational mode) `($rational rplus . ,(mapcar #'cdr args)))
@@ -41,19 +37,14 @@
 	  (t `($any add* . ,(mapcar #'dconvx args))))))
 
 (def%tr mtimes (form)
-  (let (args mode)
-    (cond ((equal -1 (cadr form))
-	   (translate `((mminus) ((mtimes) . ,(cddr form)))))
-	  (t
-	   (do ((l (cdr form) (cdr l)))
-	       ((null l))
-	     (setq args (cons (translate (car l)) args)
-		   mode (*union-mode (car (car args)) mode)))
-	   (setq args (nreverse args))
-	   (cond ((eq '$fixnum mode) `($fixnum * . ,(mapcar #'cdr args)))
-		 ((eq '$float mode) `($float * . ,(mapcar #'dconv-$float args)))
-		 ((eq '$rational mode) `($rational rtimes . ,(mapcar #'cdr args)))
-		 ((eq '$number mode) `($number * . ,(mapcar #'cdr args)))
+  (cond ((equal -1 (cadr form))
+         (translate `((mminus) ((mtimes) . ,(cddr form)))))
+        (t
+         (destructuring-bind (mode . args) (translate-args/union-mode (cdr form))
+           (cond ((eq '$fixnum mode) `($fixnum * . ,(mapcar #'cdr args)))
+                 ((eq '$float mode) `($float * . ,(mapcar #'dconv-$float args)))
+                 ((eq '$rational mode) `($rational rtimes . ,(mapcar #'cdr args)))
+                 ((eq '$number mode) `($number * . ,(mapcar #'cdr args)))
 		 (t `($any mul* . ,(mapcar #'dconvx args))))))))
 
 
@@ -147,11 +138,6 @@
 (def%tr bigfloat (form)
   `($any . ',form))
 
-(def%tr %sqrt (form)
-  (setq form (translate (cadr form)))
-  (if (eq '$float (car form)) `($float sqrt ,(cdr form))
-      `($any simplify (list '(%sqrt) ,(cdr form)))))
-
 (def%tr mabs (form) 
   (setq form (translate (cadr form)))
   (if (covers '$number (car form)) (list (car form) 'abs (cdr form))
@@ -160,16 +146,7 @@
 (def%tr %signum (form)
   (destructuring-let (( (mode . arg) (translate (cadr form))))
     (cond ((member mode '($fixnum $float) :test #'eq)
-	   (let ((temp (tr-gensym)))
-	     `($fixnum . ((lambda (,temp)
-			    (declare (,(if (eq mode '$float)	
-					   'flonum
-					   'fixnum)
-				       ,temp))
-			    (cond ((minusp ,temp) -1)
-				  ((plusp ,temp) 1)
-				  (t 0)))
-			  ,arg))))
+	   `(,mode . (cl:signum ,arg)))
 	  (t
 	   ;; even in this unknown case we can do a hell
 	   ;; of a lot better than consing up a form to
@@ -212,9 +189,7 @@
   (setq form (translate (cadr form)))
   (cond ((eq '$fixnum (car form)) form)
         ((member (car form) '($float $number) :test #'eq)
-	 (if (eq 'sqrt (cadr form))
-	     `($fixnum $isqrt ,(caddr form))
-	     `($fixnum floor ,(cdr form))))
+	 `($fixnum floor ,(cdr form)))
         (t `(,(if (eq (car form) '$rational) '$fixnum '$any)
 	     $entier ,(cdr form)))))
 
@@ -224,22 +199,3 @@
       (cons '$float (dconv-$float form))
       `($any $float ,(cdr form))))
 
-(def%tr %exp (form)
-  (setq form (translate (cadr form)))
-  (if (eq '$float (car form))
-      `($float exp ,(cdr form))
-      `($any simplify (list '(%exp) ,(cdr form)))))
-
-(def%tr $atan2 (form)
-  (setq form (cdr form))
-  (let ((x (translate (car form))) (y (translate (cadr form))))
-    (if (eq '$float (*union-mode (car x) (car y)))
-	`($float atan ,(cdr x) ,(cdr y))
-	`($any simplify (list '($atan2) ,(cdr x) ,(cdr y))))))
-
-(def%tr %atan (form)
-  (setq form (cdr form))
-  (let ((x (translate (car form))))
-    (if (eq '$float (car x))
-	`($float atan ,(cdr x))
-	`($any simplify (list '(%atan) ,(cdr x))))))
